/* ********************************************************************* */
//   Filename: ATRIUM02.POV                                              //
//   Michael Brendan Hurley for ShadowDancer Enterprizes, LTD.           //
//   from ROOMx, PANELx, WINGx                                11 Apr 97  //
//   HOUSE 00: 1st draft Our_House, Atrium, Wings             13 Apr 97  //
//   WING_1 01: new Panels, Windows, Columns, Towers          14 Apr 97  //
//    saved as DOOR01.TGA 14 APR //
//    saved as ATRIUM 01: New front door, swappable panels    14 Apr 97  //
//                    02: refinements                         14 Apr 97  //
/* ********************************************************************* */
/* ********************************************************************* */
//                           Global Definitions                          //
/* ********************************************************************* */

#include "basic.inc"                   // Lights Cameras Simple objects
#include "rooms.inc"                   // Textures, Complex Objects

/* ********************************************************************* */
/* ********************************************************************* */

// DEFINE DEFAULTS

#default { texture { ambient 0.4 } }   // ambient light

/* ********************************************************************* */

// DEFINE SKY  ***** *****

object { sphere { < 0 0 0 > 5000 }
         texture { Blue_Tex
                   ambient 1.0
                   diffuse 0.0
                 }  //end texture
         color White                   // low resolution display color
       }  //end object Sky

/* ********************************************************************* */

#declare TestSpot3 =
light_source {
   < -20 75 -10 >                       //
   color White     //green 0.95
   spotlight
   point_at < -20 0 0 >                  // Atrium, south center
   tightness 20
   radius 20
   falloff 10
             }  // end of TestSpot 3

/* ********************************************************************* */

// DECLARE TEST CAMERA  *****  set location and look_at  *****

#declare TestView =
camera {
//   location < -20 20 -110 >         // current Master shot
   location  < -70 55 -100 >       //long shot
//   location  < -20 5 -30 >      //due south Atrium center
//   location  < 25 230 -10 >       //above center of 1st room
//   location  < 40 260 -40 >       //above center of Wing1 / South Wall
   direction <   0   0   2 >
   look_at < -20 20 0 >           //Atrium center
//   look_at   < 0  20  0 >         // world center
//   look_at   <  30 0 20 >         //center of Room 1
//   look_at   < 40  10 20 >        //center of Wing 1 / South Wall
       }  //end of camera Test View

/* ********************************************************************* */
// DEFINE SCENE  *****   Room Scene Tester   ***** //
/* ********************************************************************* */
/* ********************************************************************* */
/*
// DEFINE  Door_East: right half of double swinging door     *****

#declare Door_East_Half =
composite {

   object { Plank_C                    // large door panel
            texture { DMFWood2
                      scale < 0.5 1 0.5 >
                      rotate < -10 0 0 >
                    } //end tex
            scale < 2 4.7 0.5 >             //to fit openning
//            rotate < 0 -45 0 >              //open the door
//            translate < -18 4.75 -1.1 >     //open the door
            rotate < 0 0 0 >                //close the door
            translate < -18 4.75 -1.1 >     //close the door
            color CadetBlue
          } // end object Plank C

   object { Plank_C                    // smaller door panel
            texture { Dark_Wood
                      scale < 0.5 1 0.5 >
                      rotate < -10 0 0 >
                    } //end tex
            scale < 1.75 4.3 0.5 >          //adjust to less than above
//            rotate < 0 -45 0 >              //open the door
//            translate < -18 4.75 -1.3 >      //open the door
            rotate < 0 0 0 >                //close the door
            translate < -18 4.75 -1.3 >     //close the door
            color LimeGreen
          } // end object Plank C

          }  //  end composite Door: East Half

/* ********************************************************************* */

// DEFINE  Front Door with frame and trim     *****

#declare Front_Door =                  //centered on <-20 4.75 0 >
composite {

   object { Beam_D                     // lower left of door
            scale < 0.75 1.5 1 >
            translate < -25 10 0.45 >
          } // end object Beam D
   object { Beam_D                     // lower right of door
            scale < 0.75 1.5 1 >
            translate < -15 10 0.45 >
          } // end object Beam D
   object { Plank_C                    // panel above door
            texture { pop_wood
                      scale < 0.5 1 0.5 >
                      rotate < -10 0 0 >
                    } //end tex
            scale < 4 4 0.25 >
            translate < -20 14 -0.5 >
            color LimeGreen
          } // end object Plank C

/*
   object { Plank_C                    // front door west panel
            texture { Dark_Wood
                      scale < 0.5 1 0.5 >
                      rotate < -10 0 0 >
                    } //end tex
            scale < 1.7 4.5 0.25 >
            translate < -21.6 4.75 -1.5 >
            color LimeGreen
          } // end object Plank C
*/

   object { Beam_D                     // door lintel
            scale < 0.5 0.5 0.5 >                    // +y??
            rotate < 0 0 90 >
            translate < -20 10 0 >
          } // end object Beam A

   composite { Door_East_Half }        //one half of door
   composite { Door_East_Half
               translate < -4 0 0 > }   //the other half

          }  //  end composite Front Door

/* ********************************************************************* */

#declare Wall_Panel_C2 =               // TEST COPY TO MODIFIED
composite {

   object { Beam_D                     // left
            scale < 1 1.1 1 >
            translate < -40 20 0 >
          } // end object Beam D
   object { Beam_D                     // right
            scale < 1 1.1 1 >
            translate < 0 20 0 >
          } // end object Beam D
   object { Beam_D                     // top
            rotate < 0 0 90 >
            translate < -20 40 0 >
          } // end object Beam D
   object { Beam_D                     // 2/3rds up
            rotate < 0 0 90 >
            translate < -20 30 0 >
          } // end object Beam D
   object { Beam_D                     // half up
            rotate < 0 0 90 >
            translate < -20 20 0 >
          } // end object Beam A
/*
   object { Beam_D                     // bottom
            rotate < 0 0 90 >
            translate < -20 2 0 >
          } // end object Beam A
*/
   object { Plank_C                    // vertical Wall panel
            texture { pop_wood
                      scale < 0.5 1 0.5 >
                      rotate < -10 0 0 >
                    } //end tex
            scale < 7 10 1 >
            translate < -31 10 0.45 >
          } // end object Plank C
   object { Plank_C                    // vertical Wall panel
            texture { pop_wood
                      turbulence 0.9
                      scale < 0.5 1 0.5 >
                      rotate < 10 0 0 >
                    } //end tex
            scale < 7 10 1 >
            translate < -9 10 0.45 >
          } // end object Plank C

   object { Arch_Plain
            texture { oak
                      scale < 4 3 2 >
                      rotate < 20 0 15 > }
            scale < 10 12.5 20 >
            rotate < 0 90 0 >
            translate < -20 30 0 >
          } //end object Arch Plain

   object { Window_B
            translate < -20 25 0 >
          } // end Picture Window

   composite { Front_Door }

          } // end composite Wall Panel C2
*/
/* ********************************************************************* */
/* ********************************************************************* */


// LIGHTS!                        ***** DEFINE LIGHT SOURCES

//                                ***** global lighting
//object { light_source { FloodRear } }  // high rear flood light
//object { light_source { FloodSouth } } // low front flood light
object { light_source { FloodSE2 } }   // high flood light
object { light_source { FloodSW2 } }   // high flood light

//                                ***** spots on < 0 0 0 >
//object { light_source { SpotRight1 } } // +x +y +z spot light
//object { light_source { SpotLeft1 } }  // -x +y -z spot light
//object { light_source { SpotRight2 } } // +x -y -z spot light
//object { light_source { SpotLeft2 } }  // -x +y -z spot light

//                                ***** Test Locations
//object { light_source { TestSpot1 } }  //
//object { light_source { TestSpot2 } }  //
object { light_source { TestSpot3 } }  //


/* ********************************************************************* */
// CAMERA!                        ***** POSITION CAMERA

camera { TestView }                    // Variable with each view
//camera { OverHigh }                    // < 0 650 -1 >
//camera { OverMed }                     // < 0 300 -1 >
//camera { OverLow }                     // < 0 100 -1 >

//camera { South1 }                      // <   0 20 -50 >
//camera { West1 }                       // < -50 20   0 >
//camera { North1 }                      // <   0 20  50 >
//camera { East1 }                       // <  50 20   0 >


/* ********************************************************************* */
// ACTION!                        ***** DESCRIBE SCENE

//composite { Grid_Zero  translate < 0 0 0> }

object { Test_Floor }                  // GRAY75

composite { Atrium_A }

//composite { Wall_Panel_C2 }

/* ********************************************************************* */
/* STORAGE   *****
object    { Test_Floor }
composite { Grid_Zero  translate < 0 0 0> }
composite { Grid_Plus  translate < 0 0 0> }
composite { Grid_Up    translate < 0 0 0> }
composite { Atrium_A }
composite { Wing_One }                 // east wing + ramada
composite { Wing_One                   // north wing
            rotate < 0 90 0 >
            translate < -40 0 120 > }
composite { Wing_One                   // west wing
            rotate < 0 180 0 >
            translate < -40 0 40 > }
object    { Picture_A                  //scaled & moved to
            scale < 9 9 1 >            //   be area rug
            rotate < 90 90 0 >
            translate < 30 0 20 > }
                                       // Decore
composite { Pic_Frame_A
            translate < 0 15 -11.5 > }
                                       // Landscaping
composite { Tree_B   scale < 2 2 2 >  translate <  50 0 60 > }
composite { Tree_B   scale < 2 2 2 >  translate <  80 0 60 > }
composite { Tree_B   scale < 2 2 2 >  translate < 110 0 60 > }
object    { Hedge_B  scale < 4 2 2 >  translate < 30 0  50 > }
object    { Hedge_B  scale < 4 2 2 >  translate < 30 0 -10 > }
composite { Patio_East  translate < 75 0 20 > }
*/
/* ********************************************************************* */
/* END OF   Atrium 01   FILE      ****************** */
/* ********************************************************************* */
