/* ********************************************************************* */
/*    Filename: BASIC.INC               #include file of declarations    */
/*                  Lights! Cameras! Objects! FXs!                       */
/*    Declarations of standardized cameras, lights, shapes, etc.         */
/*    for use in any PoV Ver 2.0 scene script.                           */
/*    All definitions refer to test object at <0 0 0> on plane <0 1 0>   */
/*    BASIC.INC                                AUG 96-NOV 97  Ver. 1.5   */
/* ********************************************************************* */
/* ********************************************************************* */

#include "colors.inc"                  // standard colors
#include "shapes.inc"                  // standard shapes
#include "tex.inc"                     // standard textures modified

/* ********************************************************************* */
/*                           DECLARE LIGHTS                              */
/* ********************************************************************* */

// DEFINE  Flood Lights   *****   *****

#declare FloodSE1 =
light_source { < 1000 500 -1000 >
               color White
             }  //end light Flood SE 1

#declare FloodSE2 =
light_source { < 500  700 -500 >
               color White
             }  //end of SE 2

#declare FloodSW1 =
light_source { < -1000 500 -1000 >
               color White
             }  //end light Flood SW 1

#declare FloodSW2 =
light_source { < -500 700 -500 >
               color White
             }  //end light Flood SW 2

#declare FloodNE1 =
light_source { < 1000 500 1000 >
               color White
             }  //end of NE 1

#declare FloodNE2 =
light_source { < 500 700 500 >
               color White
             }  //end of NE 2

#declare FloodNW1 =
light_source { < -1000 500 1000 >
               color White
             }  //end of NW 1

#declare FloodNW2 =
light_source { < -500 700 500 >
               color White
             }  //end of NW 2

/* ********************************** */

#declare FloodRear =
light_source
    { < -100 1000 1000 >
      color White
     }  //end light FloodRear
/* ********************************** */

#declare FloodSouth =
light_source {
   < 0 100 -1000 >
   color White
             }  //end light SouthFlood
/* ********************************** */

/*     comment out spots ***

// DEFINE   Spot Lights   *****   *****

#declare SpotLeft1 =
light_source
   { < -50 5 5 >                       // from -x +y +z toward...
     color White
     spotlight
     point_at < 0.0  5.0  0.0 >        // center of obj < 0 5 0 >
     tightness 45
     radius 25
     falloff 45
   }  //end SpotLeft1
/* ********************************** */

#declare SpotRight1 =
light_source
   { < 50 5 5 >                        // from +x +y +z toward...
     color White
     spotlight
     point_at < 0.0 5.0 0.0 >          // center of obj < 0 5 0 >
     tightness 45
     radius 25
     falloff 45
    }  //end SpotRight1
/* ********************************** */

#declare SpotLeft2 =
light_source
    { < -50 25 -20 >                    // from -x +y -z toward...
      color White
      spotlight
      point_at < 0.0 5.0 0.0 >         // center of object < 0 5 0 >
      tightness 50
      radius 10
      falloff 15
    }  //end of SpotLeft2
/* ********************************** */

#declare SpotRight2 =
light_source
    { < 50 10 -20 >                    // from +x +y -z toward...
      color White
      spotlight
      point_at < 0.0 5.0 0.0 >         // center of obj < 0 5 0 >
      tightness 75
      radius 10
      falloff 15
    }  //end of SpotRight2
/* ********************************** */

*/     //   end comment out

// DEFINE A bank of flood lights

#declare Flood_Bank1 =
composite {
object {
   light_source {
      < -252 200 -295 >                  // from south west
      color White
      point_at < 0 0 0 > }              // at center
       } // end Light 1
object {
   light_source {
      < -250 200 -295 >
      color White
      point_at < 0 0 0 > }
       } // end Light 2
object {
   light_source {
      < -249 200 -295 >
      color White
      point_at < 0 0 0 > }
       } // end Light 3
object {
   light_source {
      < -251 202 -295 >
      color White
      point_at < 0 0 0 > }
       } // end Light 4
object {
   light_source {
      < -253 202 -295 >
      color White
      point_at < 0 0 0 > }
       } // end Light 5
object {
   light_source {
      < -254 198 -295 >
      color White
      point_at < 0 0 0 > }
       } // end Light 6
object {
   light_source {
      < -254 198 -295 >
      color White
      point_at < 0 0 0 > }
       } // end Light 7
          } // end composite Flood Light Bank 1

/* ********************************** */

// DEFINE A bank of flood lights

#declare Flood_Bank2 =
composite {
object {
   light_source {
      < -752 500 -795 >                  // from south west
      color White }
       } // end Light 1
object {
   light_source {
      < -750 500 -795 >
      color White }
       } // end Light 2
object {
   light_source {
      < -749 500 -795 >
      color White }
       } // end Light 3
object {
   light_source {
      < -751 502 -795 >
      color White }
       } // end Light 4
object {
   light_source {
      < -753 502 -795 >
      color White }
       } // end Light 5
object {
   light_source {
      < -754 498 -795 >
      color White }
       } // end Light 6
object {
   light_source {
      < -754 498 -795 >
      color White }
       } // end Light 7
          } // end composite Flood Light Bank 2

/* ********************************************************************* */
/*                           DECLARE CAMERAS                             */
/* ********************************************************************* */

/*  COMMENT OUT ALL CAMERAS

// STANDARD TEST VIEW POINTS of object at world center < 0 5 0 >

#declare South1 =
camera {
  location  <  0.0   20.0  -50.0 >     // due South of center
  direction <  0.0    0.0    2.0 >
  look_at   <  0.0    5.0    0.0 >     // world center 5.0 above floor
       }  //end of camera South1
/* ********************************** */

#declare East1 =
camera {
  location  < 50.0   20.0   0.0 >      // due East of center...
  direction <  0.0    0.0   2.0 >
  look_at   <  0.0    5.0   0.0 >      // world center 5.0 above floor
       }  //end of camera East1
/* ********************************** */

#declare North1 =
camera {
   location  < 0.0  20.0  50.0 >       // due North of center
   direction < 0.0   0.0   2.0 >
   look_at   < 0.0   5.0   0.0 >       // world center 5.0 above floor
       }  //end of camera North1
/* ********************************** */

#declare West1 =
camera {
   location  < -50.0  20.0  0.0 >      // due West of center...
   direction <   0.0   0.0  2.0 >
   look_at   <   0.0   5.0  0.0 >     // world center 5.0 above floor
         }  //end of camera West1
/* ********************************** */

#declare SouthWest1 =
camera {
  location  < -25.0  20.0  -25.0 >     // SW and above...
  direction <   0.0   0.0    2.0 >
  look_at   <   0.0   5.0    0.0 >     // world center 5.0 above floor
       }  //end of camera SouthWest1
/* ********************************** */

#declare SouthEast1 =
camera {
  location  < 25.0  20.0  -25.0 >      // SE and above...
  direction <  0.0   0.0    2.0 >
  look_at   <  0.0   5.0    0.0 >      // world center 5.0 above floor
       }  //end of camera SouthEast1
/* ********************************** */

#declare NorthWest1 =
camera {
  location  < -25.0  20.0  25.0 >      // NW and above...
  direction <   0.0   0.0   2.0 >
  look_at   <   0.0   5.0   0.0 >      // world center 5.0 above floor
       }  //end of camera NorthWest1
/* ********************************** */

#declare NorthEast1 =
camera {
  location  < 25.0  20.0  25.0 >       // NE and above...
  direction <  0.0   0.0   2.0 >
  look_at   <  0.0   5.0   0.0 >       // world center 5.0 above floor
       }  //end of camera NorthEast1
/* ********************************** */

#declare SouthWest2 =
camera {
  location  < -50.0  25.0  -50.0 >     // farther SW2
  direction <   0.0   0.0    2.0 >
  look_at   <   0.0   5.0    0.0 >     // world center 5.0 above floor
       }  //end of camera SouthWest2
/* ********************************** */

#declare SouthEast2 =
camera {
  location  < 50.0  25.0  -50.0 >      // farther SE and above...
  direction <  0.0   0.0    2.0 >
  look_at   <  0.0   5.0    0.0 >      // world center 5.0 above floor
       }  //end of camera SouthEast2
/* ********************************** */

#declare NorthWest2 =
camera {
  location  < -50.0  25.0  50.0 >      // farther NW and above...
  direction <   0.0   0.0   2.0 >
  look_at   <   0.0   5.0   0.0 >      // world center 5.0 above floor
       }  //end of camera NorthWest2
/* ********************************** */

#declare NorthEast2 =
camera {
  location  < 50.0  25.0  50.0 >       // farther NE
  direction <  0.0   0.0   2.0 >
  look_at   <  0.0   5.0   0.0 >       // world center 5.0 above floor
       }  //end of camera NorthEast2
/* ********************************** */

#declare OverLow =
camera {
  location  <   0.0  100.0  -1.0 >     // low high, over world center
  direction <   0.0    0.0   2.0 >
  look_at   <   0.0    0.0   0.0 >     // world center
       }  //end of camera OverLow
/* ********************************** */

#declare OverMed =
camera {
  location  <   0.0  300.0  -1.0 >     // medium high, over world center
  direction <   0.0    0.0   2.0 >
  look_at   <   0.0    0.0   0.0 >     // world center
       }  //end of camera OverMed
/* ********************************** */

#declare OverHigh =
camera {
  location  <   0.0  650.0  -1.0 >     // way up high, over world center
  direction <   0.0    0.0   2.0 >
  look_at   <   0.0    0.0   0.0 >     // world center
       }  //end of camera OverHigh
/* ********************************** */

#declare WayOverHigh =
camera {
  location  <   0.0 1000.0  -1.0 >     // way up high, over world center
  direction <   0.0    0.0   2.0 >
  look_at   <   0.0    0.0   0.0 >     // world center
       }  //end of camera OverHigh

*/

/* ********************************************************************* */
/*                           DECLARE OBJECTS                             */
/* ********************************************************************* */

// Piriform: Looks like a hersheys kiss.
#declare Piriform =
quartic {
   < 4.0   0.0   0.0   -4.0  0.0   0.0   0.0   0.0   0.0  0.0
     0.0   0.0   0.0    0.0  0.0   0.0   0.0   0.0   0.0  0.0
     0.0   0.0   0.0    0.0  0.0   1.0   0.0   0.0   0.0  0.0
     0.0   0.0   1.0    0.0  0.0 >
        }  // end quartic

/* ********************************** */

#declare QCone_Y = quadric {           //from Pov MMShapes.INC
   <1.0 -1.0 1.0>
   <0.0 0.0 0.0>
   <0.0 0.0 0.0>
   0.0
}

/* ********************************** */

#declare QCone_Z = quadric {
   <1.0 1.0 -1.0>
   <0.0 0.0 0.0>
   <0.0 0.0 0.0>
   0.0
}

/* ********************************** */

#declare DCone =                  /* CONE POINT DOWN /POINT at 000 */
intersection {
   quadric { QCone_Y scale <1 1 1> }
   plane { <0 -1 0> 0 }
   plane { <0 1 0> 1  }
}

#declare UCone =                  /* CONE POINT UP */
intersection {
   quadric { QCone_Y scale <1 1 1> }
   plane { <0 1 0> 0   }
   plane { <0 1 0> -1 inverse }
}

#declare BiCone =                 /* 2 CONES POINTS TOGETHER */
intersection {
   quadric { QCone_Y scale <1 1 1> }
   plane { <0 1 0> 1   }
   plane { <0 1 0> -1 inverse }
}

/* ********************************************************************* */

#declare Pyramid2_A =
intersection {
   plane { <1 0 0> 1  rotate <0 0 40> }
   plane { <-1 0 0> 1 rotate <0 0 -40>}
   plane { <0 0 1> 1  rotate <-40 0 0> }
   plane { <0 0 -1> 1 rotate <40 0 0> }
   plane { <0 -1 0> 0 }
   translate <0 -1 0>
             }  //end pyramid2_a

/* ********************************************************************* */

// Scale-able finite planes.           //from PoV Shapes2.inc
#declare Square_X =  union {           // plane in x
   triangle { < 0  1 -1> < 0 -1  1> < 0  1  1>  }
   triangle { < 0  1 -1> < 0 -1  1> < 0 -1 -1>  }
}

#declare Square_Y =  union {           // plane in y
   triangle { <-1 0 1>   < 1 0 -1>  <1 0 1>  }
   triangle { <-1 0  1>  < 1 0 -1>  <-1 0 -1>}
}

#declare Square_Z =  union {           // plane in z
   triangle { <-1 1 0.0> <1 -1 0.0> <-1 -1 0.0> }
   triangle { <-1 1 0.0> <1 -1 0.0> <1 1 0.0>   }
}

/* ********************************************************************* */
/* *****  DECLARE WALL PANELS   ***** */

#declare Wall_X1 =                     //faces E/W, scales in y,z
object { union { Square_X }
         texture { Yellow_Tex }
         color Yellow }     //end of obj Wall x1

/* ********************************** */

#declare Wall_Y1 =                     //faces  , scales in
object { union { Square_Y }
         texture { Red_Tex }
         color Red }     //end of obj Wall y1

/* ********************************** */

#declare Wall_Z1 =
object { union { Square_Z }
         texture { Green_Tex }
         color Aquamarine }     //end of obj Wall z1

/* ********************************************************************* */
/* *****    DECLARE  SPHERES    ***** */

#declare Planet_Blank =                // specify texture in script file
object {
  sphere { < 0.0 0.0 0.0 > 1.0 }
       }  //end obj Planet_Blank

/* ********************************** */

#declare Planet_Mirror =
object {
  sphere { < 0 0 0 > 1.0 }
  texture { Mirror                     // this is a shiny mirror surface
            specular 1.0
            roughness 0.001
          }  // end of texture
  color Blue
       }  // end of object Planet_Mirror

/* ********************************** */

// DEFINE  Glass Sphere Zero           clear glass unit sphere

#declare GlassSphere_0 =
object {
   sphere { < 0.0 0.0 0.0 > 1.0 }
   texture { Glass_A } 
       }  //  end object Glass Sphere

/* ********************************************************************* */
/* *****     DECLARE  BOXES     ***** */

#declare Box_Plain =
object { intersection { Cube }
         color IndianRed  }  // end object Box Plain

/* ********************************************************************* */
/* DECLARE  Generic PILLARS     ***** */

#declare Pillar_Plain =
object {
  intersection { Disk_Y }
  scale < 1 1 1 >
  color Orange
       }  // end object

/* ********************************** */

#declare Pillar_A =
object {
  intersection { Disk_Y }
  scale < 1 5 1 >
       }  // end object

/* ********************************** */

#declare Pillar_B =
object {
  intersection { Disk_X }
  scale < 5 1 1 >
       }  // end object

/* ********************************** */

#declare Pillar_C =
object {
  intersection { Disk_Z }
  scale < 1 1 5 >
       }  // end object

/* ********************************************************************* */

//   DEFINE   Test Shape  *****  A generic globe on a cube  *****

#declare TestShape =
composite {
   object { box { UnitBox  scale < 1 1 1 > }
               texture { Jade  rotate < 30 0 0 > }
               color Green
          } // end obj Box
   object { Planet_Blank
               scale < 1 1 1 >
               texture { Red_Marble }
               translate < 0 2 0 >
               color Red
          } // end obj Sphere
          }  // end composite Test Shape

/* ********************************************************************* */

//   DEFINE   A Pin shaped marker   *****

#declare Push_Pin =
composite {
   object { Planet_Blank
            texture { Bronze_Metal }
            color Red
            translate < 0 10 0 > }
   object { intersection { DCone }
            texture { Bronze_Metal }
            color Blue
            scale < 2.5 2.5 2.5 >
            translate < 0 0 0 > }
   object { Pillar_Plain
            texture { Bronze_Metal }
            color Green
            scale < 0.5 5 0.5 >
            translate < 0 6 0 > }
          }  // end composite Push Pin

/* ********************************************************************* */

//   DEFINE  0.25 diameter marker rods for each axis                             *****

#declare Rod_X =                       // left/right:west/east
object {
   intersection { Disk_X }
   scale < 5 0.125 0.125 >
   texture { Yellow_Tex }
   color Yellow
       } //end obj Rod X-axis

#declare Rod_Y =                       // up/down
object {
   intersection { Disk_Y }
   scale < 0.125 5 0.125 >
   texture { Red_Tex }
   color Red
       } //end obj Rod Y-axis

#declare Rod_Z =                       // in/out:north/south
object {
   intersection { Disk_Z }
   scale < 0.125 0.125 5 >
   texture { Green_Tex }
   color Green
       } //end obj Rod Z-axis

/* ********************************************************************* */

#declare RodGrid =
composite {
   object { Rod_X }
   object { Rod_Y }
   object { Rod_Z }
          } // end composite Rod Grid

/* ********************************************************************* */

#declare Floor_Grid =
composite {
object { Rod_X  translate < 0 0  0 > }      // floor grid
object { Rod_X  translate < 0 0  1 > }
object { Rod_X  translate < 0 0  2 > }
object { Rod_X  translate < 0 0  3 > }
object { Rod_X  translate < 0 0  4 > }
object { Rod_X  translate < 0 0  5 > }
object { Rod_X  translate < 0 0  6 > }
object { Rod_X  translate < 0 0  7 > }
object { Rod_X  translate < 0 0  8 > }
object { Rod_X  translate < 0 0  9 > }
object { Rod_X  translate < 0 0 10 > }
object { Rod_Z  translate < -5 0 5 > }     // side bars
object { Rod_Z  translate < -4 0 5 > }
object { Rod_Z  translate < -3 0 5 > }
object { Rod_Z  translate < -2 0 5 > }
object { Rod_Z  translate < -1 0 5 > }
object { Rod_Z  translate <  0 0 5 > }
object { Rod_Z  translate <  1 0 5 > }
object { Rod_Z  translate <  2 0 5 > }
object { Rod_Z  translate <  3 0 5 > }
object { Rod_Z  translate <  4 0 5 > }
object { Rod_Z  translate <  5 0 5 > }
          } // end composite Floor-Grid

/* ********************************************************************* */

/*

#declare HoloDeck =
composite {
composite { Floor_Grid translate < -5 0 0 > }
composite { Floor_Grid translate <  5 0 0 > }
composite { Floor_Grid rotate < 0 0 90 > translate < -10 0 0 > }//WEST
composite { Floor_Grid rotate < 0 0 90 > translate <  10 0 0 > }//EAST
composite { Floor_Grid rotate < 90 0 0 > translate < -5 10 10 > }//rear left
composite { Floor_Grid rotate < 90 0 0 > translate <  5 10 10 > }//rear right
          } // end composite Holodeck

*/

/* ********************************************************************* */
//                             Floor Definitions                         //
/* ********************************************************************* */

#declare Test_Floor =                  // infinite plane
object { plane { < 0 1 0 > 0 }
         scale < 1 1 1 >
       }  //end of obj Test Floor

#declare Test_FloorB =                 // bounded version
object { plane { < 0 1 0 > 0 }
         scale < 1 1 1 >
         color Gray50
         bounded_by { box { UnitBox
                      scale < 500.5 0.5 500.5 > }
                    }  // end bounding
       }  //end of obj Test Floor Bounded

/* ********************************** */

#declare Plank_Tex =
texture { gradient < 1 0 0 >
          color_map {
             [ 0.0   0.25  color Gray25  color Gray25 ]
             [ 0.25  0.50  color Gray35  color Gray40 ]
             [ 0.50  0.75  color Gray85  color Gray90 ]
             [ 0.75  1.00  color Gray90  color Gray95 ]
                    }  //end of map
          scale < 1.45 5.0 1.0 >  // narrow y stripes
          ambient 0.1
          diffuse 0.2
          reflection 0.1
        }  //end of texture

/* ********************************** */

// DEFINE  Plain Plank FLOOR  *****  blue, gray planks  *****

#declare Plank_Floor =
object { plane { < 0 1 0 > 0.0 }
         texture { Plank_Tex }
         color Gray50
       }  // end object  Plank Floor

/* ********************************** */

// DECLARE FLOOR 13  *****  pale grey, blue-striped stone  *****

#declare Floor13 =
object {
   plane { <0 1 0 > 0 }
   texture { Grnt20
             scale < 2 2 1 >
             turbulence 1.4
             reflection 0.2
             specular 0.2
           }  //end tex
   scale < 3 1 3 >
   color LightGray
       }  // end obj Floor13

/* ********************************** */

// DEFINE Temple, Check Floor Scenes  *****   bounded ver. of above

#declare Floor13_B =
object {
   plane { <0 1 0 > 0 }
   texture { Grnt20
             scale < 3 2 1 >
             turbulence 0.020
             rotate < 20 0 0 >
             reflection 0.100
             specular 0.100
           }  //end tex
   scale < 3 1 3 >
   color LightGray
   bounded_by { box { UnitBox
                      scale < 200 0.5 200 > }
              }  // end bounding
       }  //end obj Floor13_B

/* ********************************************************************* */
// **********     A 3-dimensional grid of colored spheres     ********** //
/* ********************************************************************* */

#declare Grid_Mark =

object { sphere { < 0 0 0 > 1 }
         scale < 1 1 1 >
       } //end obj  GridMark

/* ********************************************************************* */

// DEFINE a co-axial grid of marks on the floor

#declare Grid_Zero =                   // x & y axis and +-50 unit marks
composite {

   object { Grid_Mark
            texture { White_Tex }
            translate <  0 0 0 >       // center of world
            scale < 2 2 2 >
            color White }

// **********   **********             +x axis
   object { Grid_Mark
            texture { Red_Tex }
            translate < 10 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 20 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 30 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 40 0 0 >
            color Red }
   object { Grid_Mark
            texture { Yellow_Tex }
            translate < 50 0 0 >
            color Yellow }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 60 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 70 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 80 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 90 0 0 >
            color Red }
   object { Grid_Mark
            texture { Green_Tex }
            translate < 100 0 0 >
            color Green }
   object { Grid_Mark
            translate < 110 0 0 >
            color Red }
   object { Grid_Mark
            translate < 120 0 0 >
            color Red }
   object { Grid_Mark
            translate < 130 0 0 >
            color Red }
   object { Grid_Mark
            translate < 140 0 0 >
            color Red }
   object { Grid_Mark
            translate < 150 0 0 >
            color Yellow }
   object { Grid_Mark
            translate < 160 0 0 >
            color Red }
   object { Grid_Mark
            translate < 170 0 0 >
            color Red }
   object { Grid_Mark
            translate < 180 0 0 >
            color Red }
   object { Grid_Mark
            translate < 190 0 0 >
            color Red }
   object { Grid_Mark
            translate < 200 0 0 >
            color Blue }

// **********   **********             -x axis
   object { Grid_Mark
            texture { Red_Tex }
            translate < -10 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < -20 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < -30 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < -40 0 0 >
            color Red }
   object { Grid_Mark
            texture { Yellow_Tex }
            translate < -50 0 0 >
            color Yellow }
   object { Grid_Mark
            texture { Red_Tex }
            translate < -60 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < -70 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < -80 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < -90 0 0 >
            color Red }
   object { Grid_Mark
            texture { Green_Tex }
            translate < -100 0 0 >
            color Green }
   object { Grid_Mark
            translate < -110 0 0 >
            color Red }
   object { Grid_Mark
            translate < -120 0 0 >
            color Red }
   object { Grid_Mark
            translate < -130 0 0 >
            color Red }
   object { Grid_Mark
            translate < -140 0 0 >
            color Red }
   object { Grid_Mark
            translate < -150 0 0 >
            color Yellow }
   object { Grid_Mark
            translate < -200 0 0 >
            color Blue }

// **********   **********             +z axis
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 10 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 20 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 30 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 40 >
            color Red }
   object { Grid_Mark
            texture { Yellow_Tex }
            translate < 0 0 50 >
            color Yellow }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 60 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 70 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 80 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 90 >
            color Red }
   object { Grid_Mark
            texture { Green_Tex }
            translate < 0 0 100 >
            color Green }
   object { Grid_Mark
            translate < 0 0 110 >
            color Red }
   object { Grid_Mark
            translate < 0 0 120 >
            color Red }
   object { Grid_Mark
            translate < 0 0 130 >
            color Red }
   object { Grid_Mark
            translate < 0 0 140 >
            color Red }
   object { Grid_Mark
            translate < 0 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < 0 0 200 >
            color Blue }

// **********   **********             -z axis
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 -10 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 -20 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 -30 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 -40 >
            color Red }
   object { Grid_Mark
            texture { Yellow_Tex }
            translate < 0 0 -50 >
            color Yellow }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 -60 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 -70 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 -80 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 -90 >
            color Red }
   object { Grid_Mark
            texture { Green_Tex }
            translate < 0 0 -100 >
            color Green }
   object { Grid_Mark
            translate < 0 0 -150 >
            color Yellow }
   object { Grid_Mark
            translate < 0 0 -200 >
            color Blue }

// **********   **********             -X -Z Quadrant   *** THE 50's
   object { Grid_Mark
            translate < -50 0 -50 >
            color Violet }
   object { Grid_Mark
            translate < -50 0 -100 >
            color Yellow }
   object { Grid_Mark
            translate < -50 0 -150 >
            color Yellow }
   object { Grid_Mark
            translate < -50 0 -200 >
            color Blue }
   object { Grid_Mark
            translate < -100 0 -50 >
            color Yellow }
   object { Grid_Mark
            translate < -100 0 -100 >
            color Yellow }
   object { Grid_Mark
            translate < -100 0 -150 >
            color Yellow }
   object { Grid_Mark
            translate < -100 0 -200 >
            color Blue }

// **********   **********             -x +z Quadrant
   object { Grid_Mark
            translate < -50 0 50 >
            color Violet }
   object { Grid_Mark
            translate < -50 0 100 >
            color Yellow }
   object { Grid_Mark
            translate < -50 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < -50 0 200 >
            color Blue }
   object { Grid_Mark
            translate < -100 0 50 >
            color Yellow }
   object { Grid_Mark
            translate < -100 0 100 >
            color Yellow }
   object { Grid_Mark
            translate < -100 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < -100 0 200 >
            color Blue }

// **********   **********             +x -z Quadrant
   object { Grid_Mark
            translate < 50 0 -50 >
            color Violet }
   object { Grid_Mark
            translate < 50 0 -100 >
            color Yellow }
   object { Grid_Mark
            translate < 50 0 -150 >
            color Yellow }
   object { Grid_Mark
            translate < 50 0 -200 >
            color Blue }
   object { Grid_Mark
            translate < 100 0 -50 >
            color Yellow }
   object { Grid_Mark
            translate < 100 0 -100 >
            color Yellow }
   object { Grid_Mark
            translate < 100 0 -150 >
            color Yellow }
   object { Grid_Mark
            translate < 100 0 -200 >
            color Blue }

// **********   **********             +x +z Quadrant
   object { Grid_Mark
            translate < 50 0 50 >
            color Violet }
   object { Grid_Mark
            translate < 50 0 100 >
            color Yellow }
   object { Grid_Mark
            translate < 50 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < 50 0 200 >
            color Blue }
   object { Grid_Mark
            translate < 100 0 50 >
            color Yellow }
   object { Grid_Mark
            translate < 100 0 100 >
            color Yellow }
   object { Grid_Mark
            translate < 100 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < 100 0 200 >
            color Blue }
          }  // end composite Grid Zero


// **********   **********   **********   **********

#declare Grid_Plus =
composite {                            // ***** Quadrant I  +20x
   object { Grid_Mark
            translate < 20 0 20 >
            color Red }
   object { Grid_Mark
            translate < 20 0 40 >
            color Red }
   object { Grid_Mark
            translate < 20 0 60 >
            color Red }
   object { Grid_Mark
            translate < 20 0 80 >
            color Red }
   object { Grid_Mark
            translate < 20 0 100 >
            color Yellow }
   object { Grid_Mark
            translate < 20 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < 20 0 200 >
            color Blue }

// **********   **********             +40x axis
   object { Grid_Mark
            translate < 40 0 20 >
            color Red }
   object { Grid_Mark
            translate < 40 0 40 >
            color Red }
   object { Grid_Mark
            translate < 40 0 60 >
            color Red }
   object { Grid_Mark
            translate < 40 0 80 >
            color Red }
   object { Grid_Mark
            translate < 40 0 100 >
            color Yellow }
   object { Grid_Mark
            translate < 40 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < 40 0 200 >
            color Blue }

// **********   **********             +60x axis
   object { Grid_Mark
            translate < 60 0 20 >
            color Red }
   object { Grid_Mark
            translate < 60 0 40 >
            color Red }
   object { Grid_Mark
            translate < 60 0 60 >
            color Red }
   object { Grid_Mark
            translate < 60 0 80 >
            color Red }
   object { Grid_Mark
            translate < 60 0 100 >
            color Yellow }
   object { Grid_Mark
            translate < 60 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < 60 0 200 >
            color Blue }

// **********   **********             +80x axis
   object { Grid_Mark
            translate < 80 0 20 >
            color Red }
   object { Grid_Mark
            translate < 80 0 40 >
            color Red }
   object { Grid_Mark
            translate < 80 0 60 >
            color Red }
   object { Grid_Mark
            translate < 80 0 80 >
            color Red }
   object { Grid_Mark
            translate < 80 0 100 >
            color Yellow }
   object { Grid_Mark
            translate < 80 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < 80 0 200 >
            color Blue }

// **********   **********             +100x axis
   object { Grid_Mark
            translate < 100 0 20 >
            color Green }
   object { Grid_Mark
            translate < 100 0 40 >
            color Green }
   object { Grid_Mark
            translate < 100 0 50 >
            color Yellow }
   object { Grid_Mark
            translate < 100 0 60 >
            color Green }
   object { Grid_Mark
            translate < 100 0 80 >
            color Green }
   object { Grid_Mark
            translate < 100 0 100 >
            color Yellow }
   object { Grid_Mark
            translate < 100 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < 100 0 200 >
            color Blue }

// **********   **********             +150 z axis
   object { Grid_Mark
            translate < 0 0 150 >
            color Yellow }
   object { Grid_Mark
            translate <  50 0 150 >
            color Yellow }
   object { Grid_Mark
            translate <  100 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < 150 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < 200 0 150 >
            color Blue }

// **********   **********             +200 z axis
    object { Grid_Mark
             translate < 0 0 200 >
             color Blue }
    object { Grid_Mark
             translate < 50 0 200 >
             color Blue }
    object { Grid_Mark
             translate < 100 0 200 >
             color Blue }
    object { Grid_Mark
             translate < 150 0 200 >
             color Blue }
    object { Grid_Mark
             translate < 200 0 200 >
             color Blue }
           }  // end composite Grid Plus


// *********   **********    **********   **********

/*

#declare Grid_Up =                     // ***** +y axis from <0 0 0>
composite {
   object { Grid_Mark
            translate < 0 10 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 20 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 30 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 40 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 50 0 >
            color Yellow }
   object { Grid_Mark
            translate < 0 60 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 70 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 80 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 90 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 100 0 >
            color Yellow }
   object { Grid_Mark
            translate < 0 110 0 >
            color Green }
   object { Grid_Mark
            translate < 0 120 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 130 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 140 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 150 0 >
            color Yellow }
   object { Grid_Mark
            translate < 0 200 0 >
            color Blue }

// *********   **********              vertical ( -y ) axis at 0 0 0
   object { Grid_Mark
            translate < 0 -10 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 -20 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 -30 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 -40 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 -50 0 >
            color Yellow }
   object { Grid_Mark
            translate < 0 -60 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 -70 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 -80 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 -90 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 -100 0 >
            color Green }
   object { Grid_Mark
            translate < 0 -150 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 -200 0 >
            color Blue }
          }  // end composite Grid Up
*/

/* ********************************************************************* */
/* END OF  BASIC.INC     Michael Brendan Hureley for SDE, Ltd.     ***** */
/* ********************************************************************* */
