/* ********************************************************************* */
/*    Filename: BRENDAN.INC             #include file of declarations    */
/*                  Lights! Cameras! Objects! FXs!                       */
/*    Declarations of standardized cameras, lights, shapes, etc.         */
/*    for use in any PoV ver 2.0 scene script.                           */
/*    Written to support the rendering of Temple1.TGA                    */
/*    Michael Brendan Hurley     for    ShadowDancer Enterprizes, Ltd.   */
/*    6 NOV 95                                               Ver. 1.0    */
/* ********************************************************************* */
/* ********************************************************************* */

#include "colors.inc"                  // standard colors
#include "shapes.inc"                  // standard shapes
#include "shapes2.inc"                 // more "      "
#include "textures.inc"                // standard textures
#include "marble.inc"                  // marbles, snakeskins
#include "stones.inc"                  // granits

/* ********************************************************************* */
/*                           DECLARE TEXTURES                            */
/* ********************************************************************* */

// DECLARE TEXTURE ***** Green surface with lavendar cloud pattern
#declare Green_World =
texture { wood
          turbulence 1.25
          color_map {
             [0.0 0.6 color LimeGreen  color ForestGreen]
             [0.1 0.6 color Yellow     color LimeGreen]
             [0.6 1.0 color LimeGreen  color Clear]
                    }  //end color map
          scale <3.5 1.0 1.0>
          diffuse 0.55
          brilliance 0.2
          reflection 0.2
        }  //end of declare texture

/* ********************************************************************* */

// DECLARE TEXTURE ***** Yellow surface with  cloud pattern

#declare Yellow_World =
texture { wood
          turbulence 0.5
          color_map {
             [0.0 0.6 color Orange     color Yellow]
             [0.1 0.6 color Yellow     color Goldenrod]
             [0.6 1.0 color Goldenrod  color Yellow]
                    }  //end of color map
          scale <2.8 1.25 3.0>
          diffuse 0.15
          brilliance 0.2
          reflection 0.2
        }  //end of declare texture

/* ********************************************************************* */

// DECLARE TEXTURE  *****  Cloudy atmosphere variant of Texture.INC version

#declare Cloudy1 =
texture { turbulence 1.2
          bozo
          color_map { //transparent to transparent
                      [0.0 0.5 color red 1   green 1   blue 1  alpha 1
                               color red 1   green 1   blue 1  alpha 1]
                      //transparent to white
                      [0.5 0.8 color red 1   green 1   blue 1  alpha 1
                               color red 1   green 1   blue 0.01]
                      //white to gray
                      [0.8 1.0 color red 1   green 1   blue 0.01
                               color red 0.7 green 0.7 blue 0.7]
                      }  //end colormap
          scale <0.4 0.058 0.4>
        }  //end of texture

/* ********************************************************************* */

// DECLARE TEXTURE *****  transparent Sapph_Agate *****

#declare Sapphire_AgateB =
texture { agate
            color_map {
              // deep blue to less deep blue
              [0.0 0.3 color red 0.0 green 0.0 blue 0.9 alpha 1.0
                       color red 0.0 green 0.0 blue 0.8 alpha 1.0]
              // less deep blue to lighter blue
              [0.3 0.6 color red 0.0 green 0.0 blue 0.8 alpha 1.0
                       color red 0.0 green 0.0 blue 0.9]
              // to transparent
              [0.6 1.0 color red 0.0 green 0.0 blue 0.9
                       color red 0.8 green 0.8 blue 1.0]
                      }  //end color map
        }  //end declare texture

/* ********************************************************************* */

// DECLARE TEXTURE  *****  copied from Ttexture.INC  *****

#declare gilt_texture =
texture {
   marble
   turbulence 0.55
   color_map {
      [0.0   0.65   color Black     color DimGray]
      [0.65  0.775  color DimGray   color SteelBlue]
      [0.775 1.001  color SteelBlue color Black]
             }  //end map
   ambient 0.05
   diffuse 0.65
   specular 1.0
   roughness 0.00002432
   reflection 0.8
   scale <10 8 8>
        }  //end of texture gilt

/* ********************************************************************* */

#declare rod_texture =
texture {
   wood
   turbulence 0.1
   color_map {
      [0.00 0.20 color red 0.33 green 0.17 blue 0.6
      color red 0.33 green 0.17 blue 0.6]
      [0.20 0.95 color red 0.33 green 0.17 blue 0.6 alpha 0.9
      color red 0.43 green 0.28 blue 0.17]
      [0.95 1.01 color red 0.43 green 0.28 blue 0.17
      color red 0.43 green 0.28 blue 0.17]
   }  //end map
   ambient 0.0005
   diffuse 0.6
   specular 1.0
   roughness 0.0006
   reflection 0.4
        }  //end of texture rod

/* ********************************************************************* */
/* ********************************************************************* */
/*                           DECLARE LIGHTS                              */
/* ********************************************************************* */

// DEFINE LIGHT SOURCE  *****  way up high and really way in *****

#declare Flood_Rear =
light_source
    { < -1500 4000 7000 >
      color White
     }  //end light FloodRear
/* ********************************** */

// DEFINE  SpotRight  SPOT LIGHT  *****  EyesRight view -x from cntr obj *****

#declare SpotRight1 =
light_source
   { < -50 5 5 >
     color White
     spotlight
     point_at < 0.0 2.0 10.0 >          // center of obj < 0 2 2 >
     tightness 45
     radius 25
     falloff 45
   }  //end spotlight SpotRight1
/* ********************************** */

#declare SpotLeft1 =
light_source
   { < 20 5 5 >
     color White
     spotlight
     point_at < 0.0 2.0 5.0 >
     tightness 45
     radius 25
     falloff 45
    }  //end spotlight SpotLeft1
/* ********************************** */

// DEFINE 2nd SPOT LIGHT ***** way above floor, out of image -y axis *****
//                       ***** spotlight on center sphere            *****

#declare SpotLeft2 =
light_source
    { < 10 10 -20 >
      color White
      spotlight
      point_at < 0.0 5.0 0.0 >
      tightness 75         //100
      radius 10            //1
      falloff 15           //5
    }  //end of spotlight SpotLeft1
/* ********************************** */

// DEFINE 3rd SPOT LIGHT ***** above floor, out of image -y axis *****
//                       ***** Eye Left at spot on obj center    *****

#declare SpotLeft3 =
light_source
    { < 40 5 5 >
      color White
//      spotlight
      point_at < 0.0 2.5 5.0 >
//      tightness 75         //100
//      radius 10            //1
//      falloff 15           //5
    }  //end of spotlight SpotLeft3
/* ********************************** */

// DEFINE LIGHT  *****  *****
#declare SpireSpotAft =                //
light_source {
   < -10 0 25 >
   color White
   spotlight
   point_at < 0.0 10.0 25.0 >            //+z aft spire
   tightness 10
   radius 1
   falloff 10
              }  //end of spotlight SpireSpot Aft
/* ********************************** */

//DEFINE LIGHT  *****  *****
#declare SpireSpotFore =               //
light_source {
   < -10 0 0 >
   color White
   spotlight
   point_at < 0.0 10.0 0.0 >            // fore spire very near 0 0 0
   tightness 10
   radius 1
   falloff 10
              }  //end of spotlight SpireSpot Fore
/* ********************************** */

// DEFINE LIGHT  *****  *****
#declare SouthFlood =
light_source {
   < 30 30 -150 >
   color White
             }  //end light SouthFlood
/* ********************************** */

//  DEFINE LIGHT  *****  *****
#declare BlobSpot =
light_source {
   < -15 55 -70 >
   color White
   spotlight
   point_at < -30 4 -10 >            // at BlobBox
   tightness 10
   radius 1
   falloff 10
             }  //end light BlobSpot
/* ********************************** */

//  DEFINE LIGHT  *****  *****
#declare HyperBoxSpot =
light_source {
   < -15 0 80 >
   color White
   spotlight
   point_at < 0 20 80 >            // at Hyperboloid
   tightness 10
   radius 1
   falloff 10
             }  //end light BlobSpot
/* ********************************** */

//  DEFINE LIGHT  *****  *****
#declare HSpot =
light_source {
   < 150 150 -150 >
   color White
   spotlight
//   point_at < 50 0 -50 >               // at Paraboloid
//   point_at < 45 0 -45>                // TetraPile 2
//   point_at < 100 0 0 >                // Octahedron
   point_at < 320 30 20 >              // Cubic Cylinder
   tightness 20
   radius 3
   falloff 20
             }  //end light HSpot
/* ********************************** */
/* ********************************************************************* */
/*                           DECLARE CAMERAS                             */
/* ********************************************************************* */

// DEFINE CAMERA *****  45 Out and Above *****
//  SPECIAL TEST VIEW of obj center < 0 5 5 > from from far left, up, out

#declare High45l =
camera {
  location  <-25.0  25.0 -25.0 >       // High 45l looks...
//  location <-25.0 -25.0 -30.0 >       // Low 45l below floor upward
  direction <  0.0   0.0   2.0 >      //
  up        <  0.0   1.0   0.0 >
  right     <  1.33  0.0   0.0 >
  look_at   <  0.0   2.5   5.0 >      // from high, left, out to right
       }  //end of camera High45l
/* ********************************** */

// DEFINE CAMERA *****  45 Out and Above *****
//  SPECIAL TEST VIEW of obj center < 0 5 5 > from from far right, up, out

#declare High45r =
camera {
  location  < 25.0  25.0 -30.0 >      // High 45r looks...
//   location < 25.0 -25.0 -30.0 >      // Low45r is below floor
  direction <  0.0   0.0   2.0 >      //
  up        <  0.0   1.0   0.0 >
  right     <  1.33  0.0   0.0 >
  look_at   <  0.0   2.5   5.0 >      // from high, right, and way out
       }  //end of camera High54r
/* ********************************** */

// DEFINE CAMERA *****  Eyes Left  *****
//  SPECIAL TEST VIEW of obj center < 0 5 5 >
//                    from from far right looking true left

#declare EyesLeft =
camera {
  location  < 25.0   5.0   5.0 >      // Eyes Left looks...
  direction <  0.0   0.0   2.0 >      //
  up        <  0.0   1.0   0.0 >
  right     <  1.33  0.0   0.0 >
  look_at   <  0.0   2.5   5.0 >      // straight from right to left
                                       //   at 2.5 above floor level
       }  //end of camera EyesLeft
/* ********************************** */

// DEFINE CAMERA *****  Eyes Right  *****
//  SPECIAL TEST VIEW of obj center < 0 5 5 >
//                    from from far left looking true right

#declare EyesRight =
camera {
  location  < -25.0   5.0   5.0 >      // Eyes Right looks...
//  location  < -40.0  11.0   4.0 >
  direction <   0.0   0.0   2.0 >      //
  up        <   0.0   1.0   0.0 >
  right     <   1.33  0.0   0.0 >
  look_at   <   0.0   2.5   5.0 >      // straight from left at
                                       //   at 2.5 above floor level
       }  //end of camera Eyes Right
/* ********************************** */

#declare HighCenter =
camera {
//   location  < 0.0  5.0  -5.0 >        // cntr  5 up  5 back
   location  < 0.0  5.0 -20.0 >        // zoom out 25 at obj level
   direction < 0.0  0.0   2.0 >        // point +z
   up        < 0.0  1.0   0.0 >        // toward the overhead
   right     < 1.33 0.0   0.0 >        // this is the right
   look_at   < 0.0  2.5   5.0 >        // center of scene or object
       }  //end of camera HighCntr
/* ********************************** */

#declare High4070 =                    // 3BLOB1 High 40 -70 Pedistal View
camera {
   location  < -15.0  40.0  -70.0 >    // High 40 70 looks...
   direction <  2.0   2.0    2.0 >     //
   up        <  0.0   1.0    0.0 >
   right     <  1.33  0.0    0.0 >
   look_at   <  5.0   2.0   12.0 >     // down to the right
                                       //   2.0 above, behind El_Base center
         }  //end of camera High 4070
/* ********************************** */

#declare High22 =                      // orig High 22 Pedistal View
camera {
  location  <  0.0  22.0  -20.0 >      // High 22 looks...
  direction <  2.0   2.0    2.0 >      //
  up        <  0.0   1.0    0.0 >
  right     <  1.33  0.0    0.0 >
  look_at   <  7.0   1.5    7.0 >      // down to the right
       }  //end of camera High 22
/* ********************************** */

#declare High4057 =                    // High 40 -57 Pedistal
camera {
  location  < -3.0  40.0  -57.0 >      // High 40 57 looks...
  direction <  2.0   2.0    2.0 >      //
  up        <  0.0   1.0    0.0 >
  right     <  1.33  0.0    0.0 >
  look_at   <  7.0   2.0    9.0 >      // down to the right
       }  //end of camera High 40 57
/* ********************************** */

// DEFINE CAMERA *****  Temple Scene  Into building  *****

#declare IntoTempleSave =
camera {
  location  < -40    3.0  12.5 >      // Zoom into temple door
//  location  <-50.0   3.0  12.5 >
//  location  <-60.0   5.0  -10.0 >
  direction <  0.0   0.0   2.0 >      //
  up        <  0.0   1.0   0.0 >
  right     <  1.33  0.0   0.0 >
  look_at   <  3.0   2.5  -10.0 >       // into temple door
       }  //end of camera IntoTemple
/* ********************************** */

// DEFINE CAMERA *****  Temple Scene  Out and Above *****

#declare HighTempleSave =
camera {
//  location  < -55.0  20.0 -15.0 >      // HighTemple looks from...
//  location  < -5 45 -15 >              // view Piriform
//  location  < -35 15 -30 >             // view BlobBox
//  location  < -25 20 -10 >             // view Cones
//  location  < -75 75 -75 >             // way high back
//  location  < 35 65 45 >               // BiCorn
//  location  < 100 25 100 >             // NE of temple at 0 0
//  location  < 0 -17 53 >               // Hyperboloid
//  location  < -40 40 -40 >             // toward cntr obj from left
//  location  < -350 50 100 >            // BiCorn Hills Two
  location  < -200 45 75 >            // NW up 50 overview, Garden1 view
  direction <   0.0   0.0   2.0 >
  up        <   0.0   1.0   0.0 >
  right     <   1.33  0.0   0.0 >
//  look_at   < -10.0   5.0   5.0 >      // ...high, left, back toward door
//  look_at   < 35 3.0 2 >               // view Piriform
//  look_at   < -30 3.5 -8 >             // view BlobBox
//  look_at   < -10 2.5 17 >             // view Cones
//  look_at   < 0 0 0 >                  // center of wolrd
//  look_at   < 75 0 70 >                // view BiCorn
//  look_at   < 0 20 80 >                // view Hyperboloid
//  look_at   < -150 0 195 >             // view BiCorn Two
  look_at   < 0 10 20 >                 // center overview, Garden1
       }  //end of camera HighTemple
/* ********************************** */

// DEFINE CAMERA *****  Due south of obj directly at center obj  *****

#declare SouthTempleSave =
camera {
//  location  < 10 15 -45 >       // SouthTemple views high, back...
//  location  < 7.5  10.0 -15.00  >
//  location  <  0.0  17.5 -65.00 >      // TetraPile
//  location  < 0 17.5 -75 >             // TetraPile 2
//  location  < 100 0 0 >                // dodec, octa, icosa-hedrons
//  location  < 250 25 -25 >             // Cubic Cylinder
  location  < 75 35 -175 >             //
  direction <  0.0   0.0   2.0 >
  up        <  0.0   1.0   0.0 >
  right     <  1.33  0.0   0.0 >
  look_at   < 100 0 0 >
//  look_at   < 320 35 25 >              // Cubic Cylinder
//  look_at   < 100 0 0 >                // Dodec, Octa, Icosahedrons
//  look_at   < 320 35 25 >
//  look_at   < 35 4 -35 >               // TetraPile 2
//  look_at   <  25   4.0 -35 >          // TetraPile
//  look_at   < -30 4.5 -2 >             //  CrystalBallRods
      }  //end of camera SouthTemple
/* ********************************** */
/* ********************************************************************* */
/*                           DECLARE OBJECTS                             */
/* ********************************************************************* */

/* Bicorn: This looks like the top part of a paraboloid, bounded
           from below by another paraboloid.                             */

#declare Bicorn =
quartic {
   < 1.0   0.0   0.0   0.0  1.0   0.0   4.0   2.0   0.0 -2.0
   0.0   0.0   0.0   0.0  0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0   1.0  0.0   3.0   0.0   4.0   0.0 -4.0
   1.0   0.0  -2.0   0.0  1.0 >
}

/* ********************************************************************* */

// DEFINE Quartic Saddle

#declare Quartic_Saddle =
quartic {
   < 0.0   0.0   0.0   0.0  0.0   0.0   0.0   4.0   0.0  0.0
   0.0   0.0   0.0   0.0  0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0   0.0  0.0   0.0   0.0   0.0   0.0 -1.0
   0.0   0.0   0.0   0.0  0.0 >
}  //end quartic

/* ********************************************************************* */

// DEFINE Unit_Cube

#declare Unit_Cube =
intersection {
   plane { < 1  0  0> 1 texture { color Clear } }
   plane { <-1  0  0> 1 texture { color Clear } }
   plane { < 0  1  0> 1 texture { color Clear } }
   plane { < 0 -1  0> 1 texture { color Clear } }
   plane { < 0  0  1> 1 texture { color Clear } }
   plane { < 0  0 -1> 1 texture { color Clear } }
             }  //end intersection

/* ********************************************************************* */

/* A drop coming out of water? A curve formed by using the equation
   y = 1/2 x^2 (x + 1) as the radius of a cylinder having the x-axis as
   its central axis. The final form of the equation is:
   y^2 + z^2 = 0.5 (x^3 + x^2)                                           */

#declare Cubic_Cylinder =
quartic {
   < 0.0   0.0   0.0   -0.5  0.0   0.0   0.0   0.0   0.0 -0.5
   0.0   0.0   0.0    0.0  0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0    0.0  0.0   1.0   0.0   0.0   0.0  0.0
   0.0   0.0   1.0    0.0  0.0 >
}

/* ********************************************************************* */

/* a cubic saddle. The equation is: z = x^3 - y^3. */

#declare Cubic_Saddle_1 =
quartic {
   <  0.0   0.0   0.0    1.0   0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0    0.0   0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0  -1.0    0.0   0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0   -1.0   0.0 >
}

/* ********************************************************************* */

/* Glob - sort of like basic teardrop shape.                             */

#declare Glob_5 =
poly { 5
   <-0.5   0.0   0.0  -0.5   0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0   0.0   1.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0   1.0   0.0   0.0 >
}

/* ********************************************************************* */

/* Variant of a lemniscate - the two lobes are much more teardrop-like.  */

#declare Twin_Glob =
poly { 6
   < 4.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0 -4.0
   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0  0.0
   1.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0  0.0
   0.0   1.0   0.0   0.0 >
}

/* ********************************************************************* */

/*  Approximation to the helix z = arctan(y/x).

  This helix (2) turns 90 degrees in the range 0 <= z <= sqrt(2)/2.  By using
  scale <2 2 2>, the helix defined below turns 90 degrees in the range
  0 <= z <= sqrt(2) = 1.4042.                                            */

#declare Helix =
object {
   intersection {
      quadric { Cylinder_Z
         scale <2.0 2.0 2.0>
         texture { color Clear }
      }
      plane { <0.0 0.0 1.0> 1.4142 texture { color Clear } }
      plane { <0.0 0.0 -1.0> 0.0 texture { color Clear } }
      quartic {
         <  0.0   0.0   0.0    0.0  0.0   0.0   0.0    0.0   0.0  0.0
         0.0   0.0   0.0    0.0  0.0   0.0  -0.1666 0.0   1.0  0.0
         0.0   0.0   0.0    0.0  0.0   0.0   0.0    0.5   0.0 -1.0
         0.0   0.0   0.0    0.0  0.0 >
      }
   }
}

/* ********************************************************************* */

/* This is an alternate Helix, using clipped_by instead of csg intersection. */

#declare Helix_1 =
object {
   quartic {
      < 0.0   0.0   0.0    0.0  0.0   0.0   0.0    0.0   0.0  0.0
      0.0   0.0   0.0    0.0  0.0   0.0  -0.1666 0.0   1.0  0.0
      0.0   0.0   0.0    0.0  0.0   0.0   0.0    0.5   0.0 -1.0
      0.0   0.0   0.0    0.0  0.0 >
   }
   clipped_by {
      quadric { Cylinder_Z scale <2.0 2.0 2.0> }
      plane { <0.0 0.0 1.0> 1.4142 }
      plane { <0.0 0.0 -1.0> 0.0 }
   }
   bounded_by {
      intersection {
         quadric { Cylinder_Z scale <2.0 2.0 2.0> }
         plane { <0.0 0.0 1.0> 1.4142 }
         plane { <0.0 0.0 -1.0> 0.0 }
      }
   }
}

/* ********************************************************************* */

/* Hyperbolic Torus having major radius sqrt(40), minor radius sqrt(12).
   This figure is generated by sweeping a circle along the arms of a
   hyperbola.                                                           */

#declare Hyperbolic_Torus_40_12 =
quartic {
   < 1.0   0.0   0.0    0.0     2.0   0.0   0.0  -2.0   0.0 -104.0
   0.0   0.0   0.0    0.0     0.0   0.0   0.0   0.0   0.0    0.0
   1.0   0.0   0.0   -2.0     0.0  56.0   0.0   0.0   0.0    0.0
   1.0   0.0  104.0   0.0   784.0 >
}

/* ********************************************************************* */

/* Lemniscate of Gerono
  This looks like two teardrops with their pointed ends connected.       */

#declare Lemniscate =
quartic {
   < 1.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0 -1.0
   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0   0.0   0.0   1.0   0.0   0.0   0.0  0.0
   0.0   0.0   1.0   0.0   0.0 >
}

/* ********************************************************************* */

/* This is a figure with a bumpy sheet on one side and something that
  looks like a paraboloid (but with an internal bubble).                 */

#declare Quartic_Loop_1 =
quartic {
   <99.0   0.0   0.0 -40.0  98.0   0.0   0.0  98.0   0.0 -99.0
   0.0   0.0 -40.0   0.0   0.0   0.0   0.0 -40.0   0.0   0.0
   -1.0   0.0   0.0  -2.0   0.0   1.0   0.0   0.0   0.0   0.0
   -1.0   0.0   1.0   0.0   0.0 >
}

/* ********************************************************************* */

/* Monkey Saddle
  This surface has three parts that sweep up and three down.  This gives
  a saddle that has a place for two legs and a tail.                     */

#declare Monkey_Saddle =
quartic {
   < 0.0   0.0   0.0   1.0  0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0  -3.0   0.0  0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0   0.0  0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0  -1.0  0.0 >
}

/* ********************************************************************* */

/* Piriform: Looks like a hersheys kiss.                                 */

#declare Piriform =
quartic {
   < 4.0   0.0   0.0   -4.0  0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0    0.0  0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0    0.0  0.0   1.0   0.0   0.0   0.0  0.0
   0.0   0.0   1.0    0.0  0.0 >
}

/* ********************************************************************* */

/* Quartic parabola - a 4th degree polynomial (has two bumps at the bottom)
   that has been swept around the z axis.                                */

#declare Quartic_Paraboloid =
quartic {
   < 0.1   0.0   0.0  0.0   0.0   0.0   0.0   0.0   0.0  -1.0
   0.0   0.0   0.0  0.0   0.0   0.0   0.0   0.0   0.0   0.0
   0.0   0.0   0.0  0.0   0.0   0.0   0.0   0.0   0.0  -1.0
   0.0   0.0  -1.0  0.0   0.9 >
}

/* ********************************************************************* */

/* Quartic Cylinder - a Space Needle?  */

#declare Quartic_Cylinder =
quartic {
   < 0.0   0.0   0.0   0.0   1.0   0.0   0.0   0.0   0.0   0.01
   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0
   0.0   0.0   0.0   1.0   0.0   0.0   0.0   0.0   0.0   0.0
   0.0   0.0   0.01  0.0  -0.01 >
}

/* ********************************************************************* */

/* Steiners quartic surface */

#declare Steiner_Surface =
quartic {
   < 0.0   0.0   0.0  0.0  1.0   0.0   0.0   1.0   0.0   0.0
   0.0   0.0   0.0  0.0  1.0   0.0   0.0   0.0   0.0   0.0
   0.0   0.0   0.0  1.0  0.0   0.0   0.0   0.0   0.0   0.0
   0.0   0.0   0.0  0.0  0.0 >
}

/* ********************************************************************* */

/* Witch of Agnesi */

#declare Witch_Hat =
quartic {
   <  0.0   0.0   0.0   0.0   0.0   0.0   1.0   0.0   0.0   0.0
   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0   0.0
   0.0   0.0   0.0   0.0   0.0   0.0   0.0   1.0   0.0   0.04
   0.0   0.0   0.0   0.0   0.04 >
}

/* ********************************************************************* */

/* very rough approximation to the sin-wave surface z = sin(2 pi x y).
   For best results, scale by something like <1 1 0.2>. */

#declare Sinsurf =
poly { 6
   < 0.0   0.0   0.0    0.0  0.0   0.0   0.0   0.0   0.0  0.0
   -1116.226 0.0   0.0    0.0  0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0    0.0  0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0    0.0  0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0    0.0  0.0   0.0   0.0   0.0   0.0 18.8496
   0.0   0.0   0.0    0.0  0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0    0.0  0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0   0.0    0.0  0.0   0.0   0.0   0.0   0.0  0.0
   0.0   0.0  -1.0    0.0 >
}

/* ********************************************************************* */

// DEFINE  ELLIPSOID  *****   *****

#declare Elli_01 =
object {
   quadric
      { Ellipsoid
      }  //end of quadric
       }  //end of obj

/* ********************************************************************* */

// DEFINE BLOB One  *****  blob  *****

#declare Blob_One =
object {
    blob {
        threshold 0.7
        component 2.0  3.1  < 4.75   3.5   6   >  //middle
        component 2.5  3.8  < 0.25   1.6   8.8 >  //left
        component 2.5  4.5  < 5.75  -0.05  8   >  //low right
         }  //end of blob
    texture {   // specify in script       Grnt20
       ambient 0.2
       reflection 0.5
       diffuse 0.5
       phong 1
            }  //end of texture
    color GreenYellow
       } //end of blob object

/* ********************************************************************* */

// DEFINE Blob Two  *****  revised to be generic, chunky  *****
//                  *****  big spheres, chunky blob comes from str=radius

#declare Blob_Two =
object {
    blob {
        threshold 0.3
        component 4.8  4.8  < 4.8   3.4   6   >  //middle
        component 5.3  5.3  <-0.5   1.8   7.6 >  //left
        component 4.3  4.3  < 6.3  -1.0   7.5 >  //low right
         }  //end of blob
    texture {   // specify in calling script, like Grnt23
            }  //end of texture
       } //end of object BlobTwo

/* ********************************************************************* */

// DEFINE THIRD BLOB *****  blob in center  *****

#declare Blob_Three =
object {
   blob { threshold 1.0
          component 2.5  2.8  < 5.0 5.5 5.0 >    //up rear
          component 2.5  2.7  < 2.5 2.8 2.0 >    //left
          component 2.0  3.7  < 11.5 2.0 2.5 >   //right
          component 4.3  4.6  < 6.3 1.0 3.0 >    //middle down
        }  //end of blob
   texture {                           // specify in script
             reflection 0.5            //default
             specular 0.5              //default
           }  //end of texture
   color GreenYellow                   // default color at low quality
       }  //end of object

/* ********************************************************************* */

// DEFINE TORUS ELEMENT *****  behind, right of center *****
// Torus having major radius sqrt(40), minor radius sqrt(12), Torus.Pov ***

#declare Torus_Alpha =
object {
   quartic {
      < 1.0   0.0   0.0    0.0     2.0   0.0   0.0   2.0   0.0 -104.0
      0.0   0.0   0.0    0.0     0.0   0.0   0.0   0.0   0.0    0.0
      1.0   0.0   0.0    2.0     0.0  56.0   0.0   0.0   0.0    0.0
      1.0   0.0 -104.0   0.0   784.0 >
           }  //end of quadric
   texture {                           // specify in script
             phong 1.0
             phong_size 10
             ambient 0.2
             diffuse 0.8
           }  //end of texture
   color Red                           // color at quality 5, 6 or less
       }  //end of Torus obj

/* ********************************************************************* */

// DECLARE ELEMENT_002T

#declare Element_002T =                // Double Cone
object { intersection { Cone_Z }
            texture { marble12
                   scale < 2 1 1 >
                 }  //end tex
            scale < 2.3 2.3 2.5 >
            translate < -10 2.5 18.7 >
            color Goldenrod
       } //end object El002 T

/* ********************************************************************* */

// DECLARE ELEMENT_004T

#declare Element_004T =                // Blob Box
composite {
   object {
      box { UnitBox
               texture { Grnt15
                         scale < 2 5 1 >
                       }  //end texture
               scale < 3 3 3 >
               color Orange
          }  //end obj UnitBox
          }  //end of obj unitbox platform
/* ********************************** */

   object { Blob_Two
               texture { Grnt5a
                         scale < 2 2 1 >
                       }  //end texture
               scale < 0.7 0.7 0.7 >
               translate < -3.5 4.0 -5 >   // on top of platform
           }  //end obj Blob
/* ********************************** */

   translate < -30 0.3 -7.5 >
          } // end of composite BlobBox

//end object El004T

/* ********************************************************************* */

// DECLARE ELEMENT_005T

#declare Element_005T =                // Piriform + glass rods
composite {
   object { quartic {
               Piriform
               texture { Blue_Sky2
                         scale < 4 2 1 >
                       }  //end texture
               scale < 6.1 10 6.1 >
               rotate < 90 0 0 >
               rotate < 0 0 90 >
               translate < 35 6 0 >    // east of Temple
               color ForestGreen
                    }  //end of quartic
          }  //end of object PiriForm
/* ********************************** */

   object { intersection { Disk_Y }    // one
            texture { Glass
                      scale < 1 1 1 >
                      brilliance 0.5
                    }  //end texture
            scale < 0.5 20 0.5 >
            translate < 34 0 -2 >
            color Yellow
          }  //end obj 1 Pillar
/* ********************************** */

   object { intersection { Disk_Y }    // two
            texture { Glass
                      scale < 1 1 1 >
                      brilliance 0.5
                    }  //end texture
            scale < 0.5 15 0.5 >
            translate < 32 0 5 >
            rotate < 0 0 90 >
            color Yellow
          }  //end obj 2 Pillar
/* ********************************** */

   object { intersection { Disk_Y }    // three
            texture { Glass
                      scale < 1 1 1 >
                      brilliance 0.5
                    }  //end texture
            scale < 0.5 20 0.5 >
            translate < 35 1 -4 >
            rotate < 50 0 0 >
            color Yellow
          }  //end obj 3 Pillar
/* ********************************** */

   object { intersection { Disk_Y }    // four
            texture { Glass
                      scale < 1 1 1 >
                      brilliance 0.5
                    }  //end texture
            scale < 0.5 10 0.5 >
            translate < 36.5 0 1 >
            color Yellow
          }  //end obj 4 Pillar
/* ********************************** */

   object { intersection { Disk_Y }    // five
            texture { Glass
                      scale < 1 1 1 >
                      brilliance 0.5
                    }  //end texture
            scale < 0.5 20 0.5 >
            translate < 33 0 -2 >
            color Yellow
          }  //end obj 5 Pillar
/* ********************************** */

   object { intersection { Disk_Z }    // six
            texture { Glass
                      scale < 1 1 1 >
                      brilliance 0.5
                    }  //end texture
            scale < 0.6 0.6 17>
            translate < 40 5 7.5 >
            color Yellow
          }  //end obj 6 Pillar
/* ********************************** */

          }  //end composite El005T

/* ********************************************************************* */

// DECLARE ELEMENT_006T

#declare Element_006T =                // pillar
object { intersection { Disk_Y }
         texture { Grnt15
                   scale < 4 2 1 >
                   brilliance 0.2
                   reflection 0.2
                 }  //end texture
         texture { Crack4
                   scale < 2 1 1 >}
         scale < 1.0 7.5 1.0 >
         translate < 1.5 0 -1 >
         color Plum
       }  //end obj El006T

/* ********************************************************************* */

// DEFINE ELEMENT_007T  *****  *****

#declare Element_007T =                // BiCorn Hills
composite {
object {
   quartic { Bicorn }  //end of quartic
      texture { DMFWood3
                scale < 3 1 1 >
                turbulence 0.4
              }  // end of texture
      scale < 13 13 13 >
      color IndianRed
       }  // end of object first hill
// // // // //

object {
   quartic { Bicorn }  //end of quartic
      texture { DMFWood2
                scale < 3 2 1 >
                turbulence 0.5
              }  // end of texture
      scale < 11 11 11 >
      translate < 4 0 -5 >
      color IndianRed
       }  // end of object 2nd hill
// // // // //

object {
   quartic { Bicorn }  //end of quartic
      texture { DMFWood3
                scale < 1 1 3 >
                turbulence 0.4
              }  // end of texture
      scale < 7 8 7 >
      translate < 10 0 2  >
      color IndianRed
       }  // end of object third hill
// // // // //

object {
   quartic { Bicorn }  //end of quartic
      texture { DMFWood4
                scale < 3 1 1 >
                turbulence 0.4
              }  // end of texture
      scale < 10 10 10 >
      translate < 17 0 -8 >
      color IndianRed
       }  // end of object 4th hill
// // // // //

object {
   quartic { Bicorn }  //end of quartic
      texture { DMFWood5
                scale < 3 1 1 >
                turbulence 0.4
              }  // end of texture
      scale < 6 4 6 >
      translate < 26 0 -13 >
      color IndianRed
       }  // end of object 5th hill
// // // // //

          }  //end composite Hills1

/* ********************************************************************* */

// DECLARE ELEMENT 008T

#declare Element_008T =
composite {
   object {
   intersection {
      quadric { Hyperboloid_Y
                texture { Grnt1
                          scale < 6 2 1 >
                        }  //end texture
                scale < 2 4.5 2 >
              }  //end quadric
      plane { < 0 1 0 >  13 }          // upper cap on shape
      plane { < 0 1 0 > -13 inverse }  // lower cap on shape
                }  //end of intersection
          }  //end obj
   object {
      box { UnitBox
            texture { Grnt15
                      scale < 4 2 1 >
                    }  //end texture
            scale < 7 2 7 >
            translate < 0 -13 0 >
           }  //end obj UnitBox
           }  //end obj
   object {
      box { UnitBox
            texture { Grnt15
                      scale < 4 2 1 >
                    }  //end texture
            scale < 6 2 6 >
            translate < 0 13 0 >
           }  //end obj UnitBox
           }  //end obj

          }  //end composite 008T

/* ********************************************************************* */

//DEFINE ELEMENT 009T

#declare Element_009T =
object {
  quadric { Paraboloid_X
            texture { Red_Marble
                      scale < 2 1 1 >
                    }  //end texture
            scale < 1 1 1 >
          }  //end quadric
  color Blue
       }  //end obj 009T

/* ********************************************************************* */

// DEFINE ELEMENT SphereRods

#declare SphereRods =
composite {
      object { sphere { < 0 0 0 > 2.15 }
               color White
               texture { color red 1 green 1 blue 1 alpha 0.75
                         ambient 0.2
                         diffuse 0.0
                         reflection 0.12
                         refraction 1.0
                         ior 1.45
                         specular 1.0 roughness 0.001
                       }  //end texture of sphere
               translate < 0 4 0 >
             }  //end obj sphere

      object { intersection { Disk_X }
               color Blue
               texture { color red 1 green 1 blue 1 alpha 0.65
                         ambient 0.2
                         diffuse 0.0
                         reflection 0.12
                         refraction 1.0
                         ior 1.45
                         specular 1.0 roughness 0.001
                       }  //end texture of DiskX
               scale < 6 1 1 >
               translate < 0 4 2.5 >
             }  //end obj DiskX

      object { intersection { Disk_Y }
               color Green
               texture { color red 1 green 1 blue 1 alpha 0.65
                         ambient 0.2
                         diffuse 0.0
                         reflection 0.12
                         refraction 1.0
                         ior 1.45
                         specular 1.0 roughness 0.001
                       }  //end texture of Disk Y
               scale < 1 5.5 1 >
               translate < 2.5 4 0 >
             }  //end obj Disk Y

      object { intersection { Disk_Z }
               color Yellow
               texture { color red 1 green 1 blue 1 alpha 0.65
                         ambient 0.2
                         diffuse 0.0
                         reflection 0.12
                         refraction 1.0
                         ior 1.45
                         specular 1.0 roughness 0.001
                       }  //end texture of Disk Z
               scale < 0.75 0.75 6 >
               translate < -2.5 4 0 >
             }  //end obj Disk Z
          }  //end composite Crystal Sphere, Rods

/* ********************************************************************* */

#declare Element_Pyramid =
object { intersection { Pyramid }
         texture { Grnt28
                   scale < 4 3 2 >
                   brilliance 0.5
                   reflection 0.5
                   specular 0.5
                 }  //end texture
         scale < 1.5 1.5 1.5 >
         translate < 0 5 5 >
         color Green
       }  //end object Elem Pyramid

/* ********************************************************************* */

#declare Element_Torus =
object { Torus_Alpha
         texture { Stone4
                   scale < 4 1 2 >
                   brilliance 0.5
                   reflection 0.5
                   specular 0.5
                 }  //end texture
         scale < 0.65 0.65 0.65 >
         translate < 0 5 5 >
         rotate < -45 0 0 >            //fore, aft
//         rotate < 0 35 0 >             //left, right
//         rotate < 0 0 45 >              //
         color Magenta
       }  //end object Elem Torus

/* ********************************************************************* */

//  Three Dimensional 4-Sided Diamond

#declare Rhomboid = intersection {
   plane { <-1.0  0.0  0.0>  1.0 rotate <0.0 0.0 -30.0> }
   plane { < 1.0  0.0  0.0>  1.0 rotate <0.0 0.0 -30.0> }
   plane { < 0.0  0.0  1.0>  1.0 }
   plane { < 0.0  0.0 -1.0>  1.0 }
   plane { < 0.0  1.0  0.0>  1.0 }
   plane { < 0.0 -1.0  0.0>  1.0 }
}

/* ********************************************************************* */

// Classic four-sided pyramids.
// The first can't be used correctly in CSG, the second can.

#declare Pyramid_A =
intersection {
   union { // This isn't true CSG, it's just used for convenience
      triangle { <-1 0 -1> <+1 0 -1> <0 1 0>  }
      triangle { <+1 0 -1> <+1 0 +1> <0 1 0>  }
      triangle { <-1 0 +1> <+1 0 +1> <0 1 0>  }
      triangle { <-1 0 +1> <-1 0 -1> <0 1 0>  }
         }  //end union
   scale <1 2 1>
   translate <0 -1 0>
             }  //end intersection

/* ********************************************************************* */

#declare Pyramid2_A =

intersection {
   plane { <1 0 0> 1  rotate <0 0 40> }
   plane { <-1 0 0> 1 rotate <0 0 -40>}
   plane { <0 0 1> 1  rotate <-40 0 0> }
   plane { <0 0 -1> 1 rotate <40 0 0> }
   plane { <0 -1 0> 0 }
   translate <0 -1 0>
             }  //end pyramid2_a

/* ********************************************************************* */

// DECLARE ELEMENT_TetraPile

#declare Element_TetraPile =
composite {

   object {
      intersection { Tetrahedron }  //end intersection
      texture { Grnt21
                scale < 1 1 1 >
              }  //end texture
      scale  < 2 2 2 >
      rotate < 45 0 0 >
      rotate < 0 0 45 >
      color Magenta
          }  //end object 1

   object {
      intersection { Tetrahedron }  //end intersection
      texture { Grnt22
                scale < 1 1 1 >
              }  //end texture
      scale < 1 1.5 1.5 >
      rotate < 45 0 0 >
      rotate < 0 45 0 >
      translate < 2.5 3 2.5 >
      color Blue
           }  //end object 2

   object {
      intersection { Tetrahedron }  //end intersection
      texture { Grnt23
                scale < 1 1 1 >
              }  //end texture
      scale  < 1.2 1 1.2 >
      rotate < 0 45 0 >
      rotate < 0 0 45 >
      translate < -1.5 0 -1.5 >
      color Green
          }  //end object 3

          } //end composite TetraPile

/* ********************************************************************* */

// DECLARE ELEMENT_Tetra_2

#declare Element_Tetra_2 =                //
composite {

composite { Element_TetraPile          // Tetrahedrons
            translate < 25 5 -35 > }

composite { Element_TetraPile
            rotate < 65 0 0 >
            translate < 30 0 -28 > }

composite { Element_TetraPile
            scale < 0.7 0.7 0.7 >
            rotate < 0 45 0 >
            translate < 25 2 -45 > }

composite { Element_TetraPile
            scale < 0.9 0.9 0.9 >
            rotate < 0 45 0 >
            rotate < 0 0 45 >
            translate < 45 3 -38 > }

composite { Element_TetraPile
            scale < 0.3 0.3 0.3 >
            rotate < 45 0 0 >
            rotate < 0 20 0 >
            translate < 38 0.52 -39 > }

object { box {                         // like lawn/ carpet under objects
               UnitBox
               texture { Cherry_Wood
                         scale < 1.5 1 1 > }
               scale < 25 1 15 >
               translate < 40 -1 -40 >
         color Yellow
             }  //end box
       }  //end obj Box Platform

          }  //end comp of comp

//end object Element_Tetra_2

/* ********************************************************************* */

// DECLARE ELEMENT_Octa

#declare Element_Octa1 =                //
object {
   intersection { Octahedron }
   texture { Grnt2
             scale < 2 1 1 >
           }  //end texture
   scale < 2 2 2 >
   color Orange
       }  //end object Elem_Octa1

/* ********************************************************************* */

// DECLARE ELEMENT_Dodeca

#declare Element_Dodeca =                //
object {
   intersection { Dodecahedron }
   texture { Grnt3
             scale < 2 1 1 > }
   scale < 2 2 2 >
   color Green
       }  //end composite Elem_Dodeca

/* ********************************************************************* */

// DECLARE ELEMENT_Icosa

#declare Element_Icosa =                //
object {
   intersection { Icosahedron }
   texture { Grnt4
             scale < 2 1 1 > }
   scale < 2 2 2 >
   color CadetBlue
       }  //end obj Elem_Icosa

/* ********************************************************************* */

// DECLARE ELEMENT_CubicCylinder

#declare Cubic_Cyl =
object {
   intersection {

      quartic {
         < 0.0   0.0   0.0   -0.5  0.0   0.0   0.0   0.0   0.0 -0.5
         0.0   0.0   0.0    0.0  0.0   0.0   0.0   0.0   0.0  0.0
         0.0   0.0   0.0    0.0  0.0   1.0   0.0   0.0   0.0  0.0
         0.0   0.0   1.0    0.0  0.0 >
         texture { Blood_Sky
                   phong 1.0
                   diffuse 0.8
                   ambient 0.2
                 }  //end texture
              }  //end quartic

      sphere { <0 0 0> 2
         texture { Blood_Sky }  //end tex sphere
             }  //end sphere

                }  //end intersection

   bounded_by {
      sphere { <0 0 0> 2.1 } }  //end bound
   color Red
   rotate <0 20 0>

       }  //end object CubicCyl

/* ********************************************************************* */
/* ********************************************************************* */
/*                           DECLARE FLOORS                              */
/* ********************************************************************* */

#declare This_Floor =
object { plane { < 0 1 0 > 0 }
         scale < 3 3 3 >
         color Navy
       }  //end of obj Floor

/* ********************************************************************* */

#declare Grid_Mark =

object { sphere { < 0 0 0 > 1 }
         texture { Tan_Wood }
         scale < 1 1 1 >
       } //end obj  GridMark

/* ********************************** */

#declare Grid_Zero =

composite {
   object { Grid_Mark                  // x axis
            translate <  0 0 0 >       // center of world
            scale < 2 2 2 >
            color Yellow }

   object { Grid_Mark
            translate < 20 0 0 >
            color Red }
   object { Grid_Mark
            translate < 40 0 0 >
            color Red }
   object { Grid_Mark
            translate < 60 0 0 >
            color Red }
   object { Grid_Mark
            translate < 80 0 0 >
            color Red }
   object { Grid_Mark
            translate < 100 0 0 >
            scale < 1.5 1.5 1.5 >
            color Yellow }

   object { Grid_Mark                  // z axis
            translate < 0 0 20 >
            color Red }
   object { Grid_Mark
            translate < 0 0 40 >
            color Red }
   object { Grid_Mark
            translate < 0 0 60 >
            color Red }
   object { Grid_Mark
            translate < 0 0 80 >
            color Red }
   object { Grid_Mark
            translate < 0 0 100 >
            scale < 1.5 1.5 1.5 >
            color Yellow }

   object { Grid_Mark                  // +20x axis
            translate < 20 0 20 >
            color Red }
   object { Grid_Mark
            translate < 20 0 40 >
            color Red }
   object { Grid_Mark
            translate < 20 0 60 >
            color Red }
   object { Grid_Mark
            translate < 20 0 80 >
            color Red }
   object { Grid_Mark
            translate < 20 0 100 >
            scale < 1.5 1.5 1.5 >
            color Yellow }

   object { Grid_Mark                  // +40x axis
            translate < 40 0 20 >
            color Red }
   object { Grid_Mark
            translate < 40 0 40 >
            color Red }
   object { Grid_Mark
            translate < 40 0 60 >
            color Red }
   object { Grid_Mark
            translate < 40 0 80 >
            color Red }
   object { Grid_Mark
            translate < 40 0 100 >
            scale < 1.5 1.5 1.5 >
            color Yellow }

   object { Grid_Mark                  // +60x axis
            translate < 60 0 20 >
            color Red }
   object { Grid_Mark
            translate < 60 0 40 >
            color Red }
   object { Grid_Mark
            translate < 60 0 60 >
            color Red }
   object { Grid_Mark
            translate < 60 0 80 >
            color Red }
   object { Grid_Mark
            translate < 60 0 100 >
            scale < 1.5 1.5 1.5 >
            color Yellow }

   object { Grid_Mark                  // +80x axis
            translate < 80 0 20 >
            color Red }
   object { Grid_Mark
            translate < 80 0 40 >
            color Red }
   object { Grid_Mark
            translate < 80 0 60 >
            color Red }
   object { Grid_Mark
            translate < 80 0 80 >
            color Red }
   object { Grid_Mark
            translate < 80 0 100 >
            scale < 1.5 1.5 1.5 >
            color Yellow }

   object { Grid_Mark                  // +100x axis
            translate < 100 0 20 >
            color Blue }
   object { Grid_Mark
            translate < 100 0 40 >
            color Blue }
   object { Grid_Mark
            translate < 100 0 60 >
            color Blue }
   object { Grid_Mark
            translate < 100 0 80 >
            color Blue }
   object { Grid_Mark
            translate < 100 0 100 >
            scale < 1.5 1.5 1.5 >
            color Blue }

   object { Grid_Mark                  // +150 z axis
            translate <   0 0 150 >
            color Yellow }
   object { Grid_Mark
            translate <  50 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < 100 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < 150 0 150 >
            color Yellow }
    object { Grid_Mark
             translate < 200 0 150 >
             color Yellow }

    object { Grid_Mark                 // +200 z axis
             translate <   0 0 200 >
             color Green }
    object { Grid_Mark
             translate < 50 0 200 >
             color Green }
    object { Grid_Mark
             translate < 100 0 200 >
             color Green }
    object { Grid_Mark
             translate < 150 0 200 >
             color Green }
    object { Grid_Mark
             translate < 200 0 200 >
             scale < 1.5 1.5 1.5 >
             color Green }

   object { Grid_Mark                  // -10x +80z axis
            translate < -10 0 80 >
            color Yellow }
   object { Grid_Mark
            translate < -10 10 80 >
            color Yellow }
   object { Grid_Mark
            translate < -10 20 80 >
            color Yellow }
   object { Grid_Mark
            translate < -10 30 80 >
            color  Yellow }
   object { Grid_Mark
            translate < -10 40 80 >
            color Yellow }
   object { Grid_Mark
            translate < -10 50 80 >
            scale < 1.5 1.5 1.5 >
            color Yellow }
   object { Grid_Mark
            translate < -10 60 80 >
            color Yellow }
   object { Grid_Mark
            translate < -10 70 80 >
            color Yellow }
   object { Grid_Mark
            translate < -10 80 80 >
            color Yellow }
   object { Grid_Mark
            translate < -10 90 80 >
            color Yellow }
   object { Grid_Mark
            translate < -10 100 80 >
            scale < 1.5 1.5 1.5 >
            color Yellow }

          }  //end of composite GridZero Altitude

/* ********************************************************************* */
/* ********************************************************************* */

// DEFINE FLOOR 1 ***** plain, basic light and dark wood tiles *****

#declare Floor1 =
object {
  plane { <0.0 1.0 0.0> 0 }
  texture {
    tiles {
      texture { White_Wood
                  scale < 1.0 0.5 0.5 >
              }
    tile2
      texture { Dark_Wood }
          }  //end of tiles
    reflection 0.6
    specular 0.6
    scale < 4 4 4 >
          }  //end of texture
       }  //end of obj

/* ********************************************************************* */

// DEFINE FLOOR 2 ***** blue,brown, gray shiny stone floor *****

#declare Floor2 =
object {
  plane { <0.0 1.0 0.0> 0 }
  texture {
    tiles {
      texture { Brown_Agate }
    tile2
      texture { Pink_Granite
                  turbulence 0.2
              }
          }  //end of tiles
    reflection 0.5
    specular 0.5
    scale < 4 4 4 >
          }  //end of texture
       }  //end of obj

/* ********************************************************************* */

// DEFINE FLOOR 3 ***** blue gray floor w/ red, pink tints *****

#declare Floor3 =
object {
  plane { <0.0 1.0 0.0> 0 }
  texture {
    tiles {
      texture { White_Marble }
    tile2
      texture { Pink_Granite
                  turbulence 1
              }
          }  //end of tiles
  reflection 0.5
  specular 0.5
  scale < 4 4 4 >
          }  //end of tex
       }  //end of obj

/* ********************************************************************* */

// DEFINE FLOOR 4 ***** pleasing light/dark tiles; darker than Floor1 *****

#declare Floor4 =
object {
  plane { <0.0 1.0 0.0> 0 }
  texture {
    tiles {
      texture { Sandalwood             //silky bluegrey
                  turbulence 5.5       //or 2.0
              }
    tile2
      texture { Dark_Wood              //shades of brown
                  turbulence 2.0       //turb up = more dark stripes
                                       //  balance both turbs to adj
                                       //  light, dark of scene
              }
          }  //end of tiles
    reflection 0.5
    specular 0.5
    scale < 4 4 4 >                    //adj size of a tile
          }  //end of tex
       }  //end of obj

/* ********************************************************************* */

// DEFINE FLOOR 5 ***** blue-gray wavy surface *****

#declare Floor5 =
object {
  plane { <0.0 1.0 0.0> 0 }
  texture { White_Marble
              scale < 1.5 2.5 1.5 >      //stretch tex along y axis
              reflection 0.5
              specular 0.5
          }  //end of tex
    scale < 4 4 4 >
       }  //end of obj


/* ********************************************************************* */

// DEFINE FLOOR 6 ***** blue-gray waves *****

#declare Floor6 =
object {
  plane { <0.0 1.0 0.0> 0 }
  texture { Sapphire_Agate
              scale < 4.0 2.0 1.0 >    //stretch x = oily surfaced waves
              turbulence 1.0
              diffuse 0.75
              brilliance 0.5
              reflection 0.5
              specular 0.5
          }  //end of tex
  scale < 4 4 4 >
       }  //end of obj

/* ********************************************************************* */

// DEFINE FLOOR 7 ***** pink-ish lavendar *****

#declare Floor7 =
object {
  plane { <0.0 1.0 0.0> 0 }
  texture { White_Wood                 //mostly pink-ish ?
              scale < 0.5 5.2 0.2 >
              turbulence 0.5
              reflection 0.5
              specular 0.5
           } //end of tex
  scale < 4 4 4 >
       }  //end of obj

/* ********************************************************************* */

// DECLARE FLOOR 8  ***** mottled red, purple *****

#declare Floor8 =
object {
  plane { <0.0 1.0 0.0> 0 }
  texture { Brass_Valley
              scale < 1.5 0.5 0.5 >
              turbulence 0.4
              reflection 0.5
              specular 0.5
           } //end of tex
  scale < 5 5 5 >
       }  //end of obj

/* ********************************************************************* */

// DECLARE FLOOR 9  *****  reddish wood, dark blue brown grain  *****

#declare Floor9 =
object {
  plane { <0.0 1.0 0.0> 0 }
  texture { Cherry_Wood
              scale < 2.8 0.5 0.5 >
              turbulence 1
              reflection 0.5
              specular 0.5
           } //end of tex
  scale < 4 4 4 >
       }  //end of obj

/* ********************************************************************* */

// DECLARE FLOOR 10  *****  Dull yellow with dark grain  *****

#declare Floor10 =
object {
  plane { <0.0 1.0 0.0> 0 }
  texture { Pine_Wood
              scale < 0.8 5.5 0.5 >
              turbulence 1
              reflection 0.5
              specular 0.5
           } //end of tex
  scale < 6 6 6 >
       }  //end of obj

/* ********************************************************************* */

// DECLARE FLOOR 11  *****  *****

#declare Floor11 =
object {
  plane { <0.0 1.0 0.0> 0 }
  texture { Jade
              scale < 1.0 1.0 1.0 >
              turbulence 2  //1
              reflection 0.3
              specular 0.3
              brilliance 0.3
           } //end of tex
  scale < 3 3 3 >
       }  //end of obj

/* ********************************************************************* */

// DEFINE FLOOR 12  *****  blue, gray planks, from Picture1 *****

#declare Plank_Floor1 =
object { plane { < 0 1 0 > 0.0 }
         texture { gradient < 1 0 0 >
                   color_map {
                     [0.0  0.25 color Gray35  color Gray35]
                     [0.25 0.50 color Gray35  color Gray40]
                     [0.50 0.75 color Gray90  color Gray95]
                     [0.75 1.00 color Gray95  color Gray95]
                             }  //end of colormap
                   scale < 1.45 5.0 1.0 >  // narrow y stripes
                   ambient 0.1
                   diffuse 0.2
                   reflection 0.2
                 }  //end of texture
       }  //end of object

/* ********************************************************************* */

// DECLARE FLOOR 13  *****  pale grey, blue stone  *****

#declare Floor13 =
object {
   plane { <0 1 0 > 0 }
   texture { Grnt20
                scale < 2 2 1 >
                turbulence 1.5
                reflection 0.3
                specular 0.3
           }  //end tex
   scale < 3 3 3 >
       }  //end obj

/* ********************************************************************* */

// DECLARE FLOOR 14  *****  tranlucent Sapphire_Agate  *****

#declare Floor14 =
object {
   plane { <0 1 0 > 0 }
   texture { Sapphire_AgateB
                scale < 7 2 10 >
                turbulence 0.85
                brilliance 0.4
                reflection 0.5
                refraction 0.1
                diffuse 0.3
           }  //end tex
   scale < 3 3 3 >
       }  //end obj Floor 14

/* ********************************************************************* */
/* ********************************************************************* */
/*                           DECLARE WALLS                               */
/* ********************************************************************* */

// These next three are finite planes.
#declare Square_X =  union {    /* Scale-able plane in x */
   triangle { < 0  1 -1> < 0 -1  1> < 0  1  1>  }
   triangle { < 0  1 -1> < 0 -1  1> < 0 -1 -1>  }
}
/* ********************************** */

#declare Square_Y =  union {    /* Scale-able plane in y */
   triangle { <-1 0 1>   < 1 0 -1>  <1 0 1>  }
   triangle { <-1 0  1>  < 1 0 -1>  <-1 0 -1>}
}
/* ********************************** */

#declare Square_Z =  union {    /* Scale-able plane in z */
   triangle { <-1 1 0.0> <1 -1 0.0> <-1 -1 0.0> }
   triangle { <-1 1 0.0> <1 -1 0.0> <1 1 0.0>   }
}
/* ********************************** */

// DECLARE GENERIC WALL PANELS  *****  *****

#declare This_Wall_1 =
object {                               // horz base line wall
   union { Square_Z }                  //
       }  //end of obj Wall 1
/* ********************************** */

#declare This_Wall_2 =
object {                               //
   union { Square_Z }                  //
       }  //end of obj Wall 2
/* ********************************** */

#declare This_Wall_3 =
object {                               //
   union { Square_Z }                  //
       }  //end of obj Wall 3
/* ********************************** */

#declare This_Wall_4 =
object {                               //
   union { Square_Z }                  //
       }  //end of obj Wall 4
/* ********************************** */
/* ********************************************************************* */
/*                             Declare Planets                           */
/* ********************************************************************* */

// DEFINE TEST PLANET  *****  *****

#declare Planet_Test =

object {
  sphere { < 0.0 0.0 0.0 > 1.0 }
  texture { Grnt19a
              scale < 1.0 1.0 1.0 >
//              turbulence 2.0
              brilliance 0.5
              reflection 0.5
              specular 0.5
//              refraction 0.15
          }  //end texture Test
       }  //end obj PlanetTest

/* ********************************************************************* */

// DEFINE  * BLANK *  PLANET  *****  standard sphere obj            *****
//                            *****    with default transformations *****

#declare Planet_Blank =

object {
  sphere { < 0.0 0.0 0.0 > 1.0 }
  texture {                            // specified in script file;
              brilliance 0.5           // neutral values in these
              reflection 0.5           //    for base line examples
              specular 0.5             //
//              refraction 0.1           //
//              phong 0.5                //
          }  //end texture Neutral Test
       }  //end obj Planet_Blank

/* ********************************************************************* */

// DEFINE FIRST PLANET ***** Green, grayish planetary surface texture *****

#declare Planet_001 =

object {
  sphere { <0.0 0.0 0.0> 1.0 }
  texture { Green_World
               phong 0.4
               reflection 0.3
          }
       }

/* ********************************************************************* */

// DEFINE SECOND PLANET ***** Yellow brown planet, dull, Dune-like  *****

#declare Planet_002 =

object {
   sphere { <0.0 0.0 0.0> 1.0 }
   texture { Yellow_World
                turbulence 2.0
                phong 0.95
                reflection 0.5
//                specular 0.5
           }  //end of texture
       }  //end of obj

/* ********************************************************************* */

// DEFINE THIRD PLANET ***** Mottled red-blue-yellow, Vulcan-like *****

#declare Planet_003 =

object {
  sphere { <0.0 0.0 0.0> 1.0 }
  texture { Blood_Sky scale <4.0 1.0 1.0>
                      turbulence 4.2
                      phong 0.3
                      reflection 0.5
          }
       }

/* ********************************************************************* */

// DEFINE THIRD Ver 2 PLANET *****

#declare Planet_003b =

object {
  sphere { <0.0 0.0 0.0> 1.0 }
  texture { Blood_Sky scale <4.0 2.0 1.0>
                      turbulence 2.6
                      reflection 0.45
          }
       }

/* ********************************************************************* */

// DEFINE THIRD Ver 3 PLANET ***** Ver 2 with cloudy atmosphere *****

#declare Planet_003c =

object {
  sphere { <0.05 0.0 0.0> 1.0 }
    // planetary surface
    texture { Blood_Sky scale <4.0 2.0 1.0>
                        turbulence 2.8
                        reflection 0.25
            }  //end texture
    // cloudy atmosphere
    texture { Cloudy1 }  //end texture
       }  //end of object

/* ********************************************************************* */

// DEFINE FOUTH PLANET ***** lavendar bands on blue, purple surface *****

#declare Planet_004 =

object {
  sphere { <0.0 0.0 0.0> 1.0 }
  texture { Red_Marble scale <10.5 2.0 6.0>
                       turbulence 6.0
          }  //end tex
       }  //end obj

/* ********************************************************************* */

// DEFINE FIFTH PLANET ***** yellow wood grain, dark stripes *****

#declare Planet_005 =

object {
  sphere { <0.0 0.0 0.0> 1.0 }
  texture { Pine_Wood scale < 6.5 3.0 2.5 >
                      turbulence 10
          }  //end texture
       }  //end object

/* ********************************************************************* */

// DEFINE SIXTH PLANET ***** dull dark blue, purple *****

#declare Planet_006 =

object {
  sphere { <0.0 0.0 0.0> 1.0 }
  texture { Sandalwood
               scale <3.0 1.0 1.0>
          }
       }

/* ********************************************************************* */

// DEFINE SEVENTH PLANET ***** rippling dark green with yellow highlights **

#declare Planet_007 =

object {
  sphere { <0.0 0.0 0.0> 1.0 }
  texture { Jade scale < 3.0 1.1 2.75 >
                 turbulence 3.5
                 reflection 0.6
                 specular 0.6
          }

 // cloudy atmosphere
 texture { Cloudy1 }
       }

/* ********************************************************************* */

// DEFINE EIGHTH PLANET ***** deep blue purple from TTexture.Inc *****

#declare Planet_008 =

object {
  sphere { <0.0 0.0 0.0> 1.0 }
  texture { rod_texture
               scale <4.0 1.0 4.0>
               turbulence 0.7
               specular 0.0
               reflection 0.4
          }  //end obj
       }  //end obj

/* ********************************************************************* */

// DEFINE NINTH PLANET *****  Mirror world  *****

#declare Planet_009 =

object {
  sphere { <0.0 0.0 0.0> 1.0 }
  texture { Grnt16a                    // or any tex to be mirror-ed
              scale < 4 2 2 >
              diffuse 0.9
              reflection 1.0
              brilliance 10.0
              specular 1.0
              roughness 0.03
          }
       }

/* ********************************************************************* */

// DEFINE TENTH PLANET  *****  Apocalypse  *****

#declare Planet_010 =

object {
  sphere { <0.0 0.0 0.0> 1.0 }
  texture { Apocalypse
              scale <4.0 2.0 2.0>
              turbulence 5.5
              brilliance 0.7
              reflection 0.7
              specular 0.5
//            phong 0.5
          }
       }

/* ********************************************************************* */

// DEFINE ELEVENTH PLANET  *****  translucent rosy quartz  *****

#declare Planet_011 =

object {
  sphere { <0.0 0.0 0.0> 1.0 }
  texture { Grnt17a
              scale < 10.0 2.0 2.0 >
              turbulence 2.5
              brilliance 0.4
              reflection 0.8
          }  //end tex
       }  //end obj

/* ********************************************************************* */

// DEFINE TWELVETH PLANET  *****  translucent cloudy crystal  *****

#declare Planet_012 =

object {
  sphere { < 0.0 0.0 0.0 > 1.0 }
  texture { Grnt20a
              scale < 10.0 2.0 2.0 >
              turbulence 2.0
              brilliance 0.3
              reflection 0.5
              refraction 0.15
          }  //end tex
       }  //end obj

/* ********************************************************************* */
/* ********************************************************************* */

// DEFINE  COMPOSITE Tower of Spheres with Ellip Pedistal  *****  *****

#declare TowerSphere =

composite {
   // DECLARE Element One  *****
   object {
      Planet_007                       // Jade
         scale     < 1.8  1.8  1.8 >
         translate < 5.0  0.0  0.0 >
         translate < 0.0  1.5  0.0 >
         translate < 0.0  0.0  5.0 >
          }  //end of obj Elem One

   // DECLARE Element Two  *****
   object {
      Planet_Blank
         texture { Stone9              // alts Stone12, 8, 3
                   scale < 2.2 1.2 1 >
                   reflection 0.75
                 }  //end texture
         scale     < 1.5  1.5  1.5 >
         translate < 5.0  0.0  0.0 >
         translate < 0.0  3.0  0.0 >
         translate < 0.0  0.0  5.0 >
          } //end of obj Elem Two


   // DECLARE Element Three  *****
   object {
      quadric {
         Ellipsoid
            texture { Glass            // SpringGreen
                      brilliance 0.88
                      reflection 0.98
                      refraction 0.2
                    }  //end texture
            scale     < 1.0  1.7  1.0 >
            translate < 5.0  0.0  0.0 >  // center of tower x y z
            translate < 0.0  5.0  0.0 >
            translate < 0.0  0.0  5.0 >
              }  //end of quadric
          }  //end of obj ElemThree

   // DECLARE Element  Four  *****
   object {
     Planet_Blank                      // same as Element_Two
        texture { Stone9
                  scale < 2.5 1.2 1 >
                  reflection 0.75
                  turbulence 2.0
                }  //end texture
        scale     < 1.5  1.5  1.5 >
        translate < 5.0  0.0  0.0 >
        translate < 0.0  7.0  0.0 >
        translate < 0.0  0.0  5.0 >
          }  //end obj ElemFour

   // DECLARE Element  Five  *****
   object {
       Planet_007                       // same as Element_One
         scale     < 2.0  2.0  2.0 >
         translate < 5.0  0.0  0.0 >
         translate < 0.0  8.5  0.0 >
         translate < 0.0  0.0  5.0 >
          }  //end of obj ElemFive

   // DECLARE Element Pedistal_Base
   object {
      Elli_01
         texture { Blood_Sky
                   scale < 3 1 1 >
                   turbulence 2.0
                 }  //end texture
         scale     < 8.0  1.45 2.8 >   //
         translate < 5.0  0.0  0.0 >   //camera, lights look here
         translate < 0.0  0.3  0.0 >   //   "       "
         translate < 0.0  0.0  5.0 >   //   "       "
          }  //end of obj Pedistal_Base

// DEFINE composite scale, movements in calling script file
      }  //end composite TowerSphere

/* ********************************************************************* */
/* ********************************************************************* */

// DECLARE ELEMENT_003T

#declare Element_003T =                // Pedistal

composite {
   TowerSphere
      scale  < 1.2 1.2 1.2 >           // scale Tower
      rotate < 0 90 0 >                //  ... from ped5c file
      translate <2.5 0.0 18.0 >        // to center of Temple
          }  //end of composite TowerSphere

//end object El003T

/* ********************************************************************* */
/* ********************************************************************* */

// DECLARE  Composite Temple A  *****  3 walls, pyramid roof, pyr spires ***
//                      *****  Temple ver 1.0

#declare Temple_A =

composite {

object { This_Wall_1
            texture { Yellow_World
               scale < 2 4 1 >
               turbulence 1.75
               reflection 0.2
               specular 0.2
               refraction 0.2
                    }  //end of texture
            scale < 5 5 5 >
            translate < 5 0 0 >        // horz wall 5 over 5 in
                                       // up left cornr touches sphere
            color Red                  // low res default color
       }  //end of obj Square_Z wall 1
/* ********************************** */

object { This_Wall_3
            texture { Yellow_World
               scale < 2 4 1 >
               turbulence 1.75
               reflection 0.2
               specular 0.2
               refraction 0.2
                     }  //end of texture
            scale < 5 5 5 >
            translate < 5 0 10 >
            color LightBlue
       }  //end obj Wall 3
/* ********************************** */

object { This_Wall_4
            texture { Yellow_World
               scale < 2 4 1 >
               turbulence 1.75
               reflection 0.2
               specular 0.2
               refraction 0.2
                     }  //end of texture
            scale < 5 5 5 >
            rotate < 0 90 0 >
            translate < 10 0 5 >
            color Green
       }  //end obj Wall 4
/* ********************************** */

object { intersection { Pyramid }      // roof
         texture { snake_skin
                   scale < 2.0 2.2 1.0 >
                   brilliance 0.5
                   reflection 0.5
                   specular 0.5
                   diffuse 0.4
                 }  //end texture
         scale < 5 3 5 >
         translate < 5 8 5 >
         color Turquoise
       }  //end object Roof Pyramid
/* ********************************** */

object { intersection { Pyramid }      // spire fore
         texture { marble2             // dark silky blue gray red
                   scale < 4 1 2 >
                   brilliance 0.2
                   reflection 0.2
                 }  //end texture Pyrm Spire Fore
         texture { marble4            // overlay black w/ red lines
                   scale < 1 0.5 1 > }  //  Excellent effect!
         scale < 2.0 17.0 1.4 >
         translate < 0.7 0.0 0.0 > //< 0.7 11 0.5 >
         color Sienna
       }  //end object spire Fore
/* ********************************** */

object { intersection { Pyramid }      // spire Aft
         texture { marble2
                   scale < 4 1 2 >
                   brilliance 0.2
                   reflection 0.2
                 }  //end texture Pyrm Spire Aft
         texture { marble4             // overlay black w/ red lines
                   scale < 0.5 1 1 > }   //   Excellent!
         scale < 2.0 17.0 1.4 >
         translate < 0.7 0.0 10.0 >
         color Sienna
       }  //end object spire Aft

          }  //end composite Temple_A    // Temple A Prototype  *****

/* ********************************************************************* */
/* END OF  Brendan.Inc  FILE  ********** */
/* ********************************************************************* */
