/* ********************************************************************* */
//   Filename: CKFLOOR1.POV                   A PoV Ver 2.0, Script File //
//   Michael Brendan Hurley      for      ShadowDancer Enterprizes, LTD. //
//   TEMPLE Scene as a checker board of Floors            Oct 96 Ver 1.0 //
//     Center: Temple_B      NE+1: Level1        NW+1: Circle w/ Lamps   //
//                           SE+1: HoloDeck      SW+1  Shrine Grove      //
//   This script generated CKFLOOR1.TGA in about 38 hours (486/100MHg)   //
/* ********************************************************************* */
//
//        This .POV file  contains  the  script  for the  entire set
//        of  Temple  and  Gardens  of  Objects  scenes.  The master
//        overview scene is generated when this file is run unedited
//        as seen in  CKFLOOR1.TGA.  By using the "comment out" pro-
//        cedure of this scripting language  and  with  redefinition
//        of the camera position all the other views in this package
//        can be made.   NW1, NE1, SW1, and SE1.TGAs  are the scenes
//        the same-named Floors.  TEMPLE1, GARDEN.TGA, etc.  are the
//        images of  the Central Floor.   All the other  pictures in
//        this set are of individual objects on various Floors.
//        I invite you to move the camera to an empty Floor and make
//        up a scene of your own.  Please send me a copy of your new
//        script so I can add it ( with credit ) to future versions.
//
/* ********************************************************************* */
//                           Global Definitions                          //
/* ********************************************************************* */

#include "basic.inc"                   // Lights Cameras Simple objects
                                       //   generic declares for any scene

#include "temple.inc"                  // Complex objects for this scene
                                       //   and it's sub-scenes

/* ********************************************************************* */
/* ********************************************************************* */

// DEFINE GLOBAL DEFAULTS

#default { texture { ambient 0.4 } }   // ambient light

/* ********************************** */

//DEFINE SKY  *****   fuzzy strings of color   *****

object { sphere { < 0 0 0 > 35000 }
         texture { Sky_Agate
            scale < 6000 90000 6000 >
            rotate < 55 0 0 >
            ambient 0.3
            diffuse 0.0
                 }  //end texture
         texture { Sky_Agate2
            scale < 5800 90000 5700 >
            rotate < 51 0 0 >
            ambient 0.3
            diffuse 0.0
                 }  //end texture
         color White                   // low resolution display color
       }  //end object Sky

/* ********************************** */

// DECLARE TEMPLE CAMERA  *****  *****

#declare TestView =
camera {
  location  < -1500  1000 -2000 >      // high, back South East of ...
  direction <   0.0   0.0   2.0 >
  up        <   0.0   1.0   0.0 >
  right     <   1.33  0.0   0.0 >
  look_at   <   0.0   0.0   0.0 >      // ... world center < 0 0 0 >
       }  //end of camera Test View

/* ********************************************************************* */
/* ********************************************************************* */

// DEFINE SCENE  *****  A Checkered Pattern of Floors        *****
//               *****  each with a Garden-of-Objects Scene  *****

// ******************************************************************** //

// LIGHTS!                        ***** DEFINE LIGHT SOURCES
//                                ***** for all scenes
object { light_source { FloodRear } }  // high rear flood light
object { light_source { FloodSouth } } // low front flood light
object { light_source { FloodSE } }    // high checker flood light
object { light_source { FloodSW } }    // high checker flood light

//                                ***** for center floor
//object { light_source { SpotRight1 } } // +x +y +z spot light
//object { light_source { SpotLeft1 } }  // -x +y -z spot light
//object { light_source { SpotRight2 } } // +x -y -z spot light
//object { light_source { SpotLeft2 } }  // -x -y -z spot light
//object { light_source { HTSpot1 } }    // on HyperTower from +50y west
//object { light_source { HTSpot2 } }    // on HyperTower from +50y east
//object { light_source { TPSpot1 } }    // on TetraPile from +60y west
//object { light_source { TPSpot2 } }    // on TetraPile from +60y east
//object { light_source { POSSpot1 } }   // on SW Pile o Spheres
//object { light_source { BBSpot1 } }    // on SW Blob Box
//object { light_source { SRSpot1 } }    // on NE Sphere Rods
//object { light_source { TGSpot } }     // on SW Twin Globs

//                                ***** for other floors
object { light_source { NWSpot } }     // on NW +1 center
object { light_source { NESpot } }     // on NE +1 center
object { light_source { SWSpot } }     // on SW +1 center
object { light_source { SESpot } }     // on SE +1 center
//object { light_source { FootSpot1} }   // NW+1 pillar foot light


// ********************************************************************* //

// CAMERA!                        ***** Position camera

camera { TestView }                    // Variable with each view
//camera { OverHigh }                    // < 0 600 -1 >
//camera { OverMed }                     // < 0 300 -1 >
//camera { OverLow }                     // < 0 100 -1 >

//camera { South1 }                      // <   0 15 -50 >
//camera { West1 }                       // < -50 15   0 >
//camera { North1 }                      // <   0 15  50 >
//camera { East1 }                       // <  50 15   0 >

//camera { SouthWest1 }                  // < -25 15 -25 >
//camera { SouthWest2 }                  // < -50 15 -50 >
//camera { NorthWest1 }                  // < -25 15  25 >
//camera { NorthWest2 }                  // < -50 15  50 >

//camera { SouthEast1 }                  // < 25 15 -25 >
//camera { SouthEast2 }                  // < 50 15 -50 >
//camera { NorthEast1 }                  // < 25 15  25 >
//camera { NorthEast2 }                  // < 50 15  50 >

// ********************************************************************* //

// ACTION!                        ***** Position objects

#declare ChekFloor1 =                  // Checker patern of Floors
composite {
   composite {                         // Central Floor
      object { Floor13_B }
      composite { Temple_B                  // Ver B Temple
                  scale < 2 2 2 >
                }  // end composite Temple
      composite { Element_Tetra_3
                  translate < 13 0 -13 >    // S and E of temple
                  scale < 1.11 1.11 1.11 >
                }  // end composite Tetra 2
      composite { BiCorn_Hills              // Hills in wood textures
                  scale < 1.5 1.5 1.5 >
                  rotate < 0 25 0 >         // rotate obj +y = right
                  translate < 120 0 30 >    // due E of temple
                } // end of composite BiCorn 1
      composite { BiCorn_Hills              // Bi-Corn Hills in wood textures
                  scale < 3.2 1.50 2.70 >
                  translate < -60 0 220 >   // NW of 0 0 0
                  rotate < 0 -40 0 >        // rotate obj -y = to left
                } // end of composite BiCorn 2
      composite { Piri_Glass_B
                  translate < 50 0.5 -6 >   // due East of temple
                }  // end of composite Piri_Glass
      object { Element_Octa1
               rotate < 0 40 0 >
               translate < -22 5 22 >       // just N & W of temple
             }  // end of object Octa1
      composite { Blob_Box_B
                  translate < -35 0.3 -13 > // just SW of temple
                }  // end of composite Blob_Box
      composite { SphereRod_B               // NW of temple
                  translate < -32 4 35 >
                }  // end composite SphereRod B
      composite { HyperTower                // NE of temple
                  translate < 44 10 57 >
                }  // end composite HyperTower
      composite { Pile_O_Spheres            // SW of temple
                  scale < 0.9 0.9 0.9 >
                  rotate < 0 0 80 >
                  translate < -50 0 -20 >
                }  // end composite P O S
      composite { Twin_Glob_B               // SW of temple
                  translate < -13 0 -28 >
                }  // end composite T_Globs
             }                         // end of Central floor

/* ********************************************************************* */

   composite {                         // start of NE+1  *****
      object { Floor13_B
                 translate < 400 0 400 > }
      object {                              // Pillar NE
         intersection { Disk_Y }
                        texture { Yellow_World
                        turbulence 0.1      // Mix colors
                        rotate < 33 0 0 >   // tilt texture on
                        rotate < 0 15 0 >   //   the object
                               } // end texture
         scale < 5 60 5 >                   // Enlarge entire obj
         translate < 460 1 460 >            // move obj
         color Yellow                       // Low res. color
             } // end obj CenterPole2
      object {                              // Pillar NNE
         intersection { Disk_Y }
                        texture { Sapphire_AgateB
                        turbulence 0.0      // Mix colors
                        rotate < 33 0 0 >   // tilt texture on
                        rotate < 0 15 0 >   //   the object
                      } // end texture
         scale < 4 25 8 >                   // Enlarge entire obj
         translate < 350 0 465 >            // move obj
         color Blue                         // Low res. color
          } // end obj CenterPole3
      composite { Pile_O_Spheres            // SW of temple
                  scale < 2 2 2 >
                  rotate < 0 0 0 >
                  translate < 530 1 395 >
                }  // end composite P O S
      composite { Level1                    // Ring temple
                  translate < 445 0 430 >
                  scale < 0.9 0.9 0.9 >
                } // end composite Ring
             } // end composite             end of NE +1   **********

/* ********************************************************************* */

   composite {                         // start of SE+1    **********
      object { Floor13_B
               translate < 400 0 -400 > }
      composite { HoloBox                   // the HoloDeck Room
                    translate < 400 0 -400 > }
      object { intersection { Pyramid }     // 1 of 3 shapes in the Room
                  texture { Red_Marble
                               scale < 2 2 2 > }
                  scale < 3 3 3 >
                  translate < 425 10 -365 >
                  color Red }
      object { box { UnitBox                // 2 of 3
                     scale < 3 3 3 > }
                 texture { White_Marble }
                 translate < 425 10 -375 >
                 color Blue
             } // end obj UnitBox
      object { Planet_Blank                 // 3 of 3
                 scale < 3 3 3 >
                 texture { White_Marble }
                 translate < 425 10 -385 >
                 color Green
             } // end obj Sphere
      composite { Tubes                     // pipe thing
                    rotate < 90 0 0 >
                    translate < 560 10 -480> }
      composite { Tubes                     // pipe thing
                    translate < 333 30 -520> }
      object { intersection { Pyramid }     //
                  texture { Red_Marble
                               scale < 2 2 2 > }
                  scale < 13 13 13 >
                  translate < 300 0 -400 >
                  color Red } //end obj Pyramid
      object { box { UnitBox                //
                     scale < 4 4 4 > }
                 texture { White_Marble }
                 translate < 300 5 -300 >
             } // end obj UnitBox
      object { Pillar_B                     // tube floating in air
                 texture { Yellow_Tex }
                 scale < 5 2 2 >
                 translate < 550 50 -300 >
             } // end obj Pillar B
      object { Pillar_C                     // tube floating in air
                 texture { Yellow_Tex }
                 scale < 2 2 4 >
                 translate < 300 50 -350 >
             } // end obj Pillar C
      object { Center_Pole                  // east edge center
                 texture { Blood_Sky }
                 scale < 0.125 4 0.125 >
                 translate < 595 0 -400 >
             }  // end object
      object { Center_Pole                  // north edge center
                 texture { Blood_Sky }
                 scale < 0.125 4 0.125 >
                 translate < 400 0 -205 >
             }  // end object
      object { Center_Pole                  // west edge center
                 texture { Blood_Sky }
                 scale < 0.125 4 0.125 >
                 translate < 205 0 -400 >
             }  // end object
      object { Center_Pole                  // south edge center
                 texture { Blood_Sky }
                 scale < 0.125 4 0.125 >
                 translate < 400 0 -595 >
             }  // end object
                                       // vertical grid markers
      composite { Grid_Up                    // SW corner
                  translate < 200 0 -600 > }
      composite { Grid_Up                    //   "        "
                  translate < 300 0 -600 > }
      composite { Grid_Up                    //   "        "
                  translate < 500 0 -600 > }
      composite { Grid_Up                    // SE corner
                  translate < 600 0 -600 > }
      composite { Grid_Up                    //   "        "
                  translate < 200 0 -500 > }
      composite { Grid_Up                    //   "        "
                  translate < 300 0 -500 > }
      composite { Grid_Up                    //   "        "
                  translate < 400 0 -500 > }
      composite { Grid_Up                    //   "        "
                  translate < 500 0 -500 > }
      composite { Grid_Up                    //   "        "
                  translate < 600 0 -500 > }
      composite { Grid_Up                    //   "        "
                  translate < 300 0 -400 > }
      composite { Grid_Up                    //   "        "
                  translate < 400 0 -400 > }
      composite { Grid_Up                    //   "        "
                  translate < 500 0 -400 > }
      composite { Grid_Up                    //   "        "
                  translate < 200 0 -300 > }
      composite { Grid_Up                    //   "        "
                  translate < 300 0 -300 > }
      composite { Grid_Up                    //   "        "
                  translate < 400 0 -300 > }
      composite { Grid_Up                    //   "        "
                  translate < 500 0 -300 > }
      composite { Grid_Up                    //   "        "
                  translate < 600 0 -300 > }
      composite { Grid_Up                    // NW corner
                  translate < 200 0 -200 > }
      composite { Grid_Up                    //   "        "
                  translate < 300 0 -200 > }
      composite { Grid_Up                    //   "        "
                  translate < 500 0 -200 > }
      composite { Grid_Up                    // NE corner
                  translate < 600 0 -200 > }
             }  // end composite          end of SE+1      **********

/* ********************************************************************* */

   composite {                         // start of NW+1    **********
      object { Floor13_B
               translate < -400 0 400 > }
      composite { Column_1                  // lamp post
                  translate < -300 0 300 > }     // SE
      composite { Column_1
                  translate < -500 0 300 > }     // SW
      composite { Column_1
                  translate < -500 0 500 > }     // NW
      composite { Column_1
                  translate < -300 0 500 > }     // NE
      composite { Column_2                 // regular post
                  translate < -360 0 430 > }     // EAST
      composite { Column_2
                  translate < -360 0 370 > }
      composite { Column_2
                  translate < -370 0 440 > }     // NORTH
      composite { Column_2
                  translate < -430 0 440 > }
      composite { Column_2
                  translate < -440 0 430 > }     // WEST
      composite { Column_2
                  translate < -440 0 370 > }
      composite { Column_2
                  translate < -370 0 360 > }     // SOUTH
      composite { Column_2
                  translate < -430 0 360 > }
      object { Box_Plain
               texture { Grnt28
                         scale < 4 1 1 >
                         rotate < 0 30 0 >
                       } // end texture
               scale < 7.5 1.5 2 >
               rotate < 0 -45 0 >
               translate < -435 20.5 435 >     // NE
               color Violet
             }  // end obj Box
      object { Box_Plain
               texture { Grnt28
                         scale < 4 1 1 >
                         rotate < 0 30 0 >
                       } // end texture
               scale < 7.5 1.5 2 >
               rotate < 0 -45 0 >
               translate < -365 20.5 365 >     // SW
               color Violet
             } // end box
      object { Box_Plain
               texture { Grnt28
                         scale < 4 1 1 >
                         rotate < 0 30 0 >
                       } // end texture
               scale < 7.5 1.5 2 >
               rotate < 0 45 0 >
               translate < -365 20.5 435 >     // NW
               color Violet
             }  // end obj Box
      object { Box_Plain
               texture { Grnt28
                         scale < 4 1 1 >
                         rotate < 0 30 0 >
                       } // end texture
               scale < 7.5 1.5 2 >
               rotate < 0 45 0 >
               translate < -435 20.5 365 >     // SW
               color Violet
             }  // end obj Box
      composite { Circle_A                  // ring of pillars, globes
                  scale < 2.2 2.2 2.2 >
                  translate < -400 0 400 >  //    center of NW+1
                }  // end of Object Circle A
             }  // end of composite              NW +1     ***********

/* ********************************************************************* */

   composite {                         // start of SW +1 floor ******
      object { Floor13_B
               translate < -400 0 -400 > }
      composite { Grove_A                        // NE of Idol
                  rotate < 0 90 0 >
                  translate < -320 0 -310 > }
      composite { Grove_A                        // NE2
                  scale < 0.7 0.9 0.7 >
                  rotate < 0 111 0 >
                  translate < -320 0 -380 > }
      composite { Grove_A                        // NW
                  scale < 1.2 1.2 1.2 >
                  translate < -480 0 -340 > }
      composite { Grove_A                        // SE
                  translate < -310 0 -410 > }
      composite { Grove_A                        // SW
                  rotate < 0 150 0 >
                  scale < 1.4 1.3 1.4 >
                  translate < -500 0 -465 > }
      composite { Grove_A                        // S
                  rotate < 0 -15 0 >
                  scale < 0.8 0.8 0.8 >
                  translate < -410 0 -475 > }
      composite { Grove_A                        // S1
                  rotate < 0 55 0 >
                  scale < 0.8 0.8 0.8 >
                  translate < -380 0 -475 > }
      composite { Grove_A                        // S2
                  rotate < 0 -35 0 >
                  scale < 0.85 0.85 0.85 >
                  translate < -300 0 -445 > }
      composite { Grove_A                        // S3
                  rotate < 0 -99 0 >
                  scale < 0.6 0.8 0.6 >
                  translate < -280 0 -495 > }
      composite { Row_Of_Trees                   // SW
                  rotate < 0 -45 0 >
                  translate < -440 0 -440 > }
      composite { Row_Of_Trees                   // SE
                  rotate < 0 45 0 >
                  translate < -360 0 -440 > }
      composite { Row_Of_Trees                   // NE
                  rotate < 0 -45 0 >
                  translate < -360 0 -395 > }
      composite { Row_Of_Trees                   // NW
                  rotate < 0 45 0 >
                  translate < -440 0 -395 > }
      composite { Wall_A                    // boxes form a checkered wall
                  translate < -400 -4 -390 > }
      object { Statue_A                     // Female figure
               translate < -400 0 -400 > }
             }  // end composite       end of SW +1        *********

/* ********************************************************************* */
// Follow the pattern set above and you can create scenes on any
// of these Floors.  Remember to translate the cameras, lights and
// your new objects to the location of the floor you choose.
/* ********************************************************************* */

   object { Floor13_B                       // E +2
              translate <  800 0    0 > }
   object { Floor13_B                       // N +2
              translate <    0 0  800 > }
   object { Floor13_B                       // S +2
              translate <    0 0 -800 > }
   object { Floor13_B                       // W +2
              translate < -800 0    0 > }

   object { Floor13_B                       // SE +2
              translate <  800 0 -800 > }
   object { Floor13_B                       // NE +2
              translate <  800 0  800 > }
   object { Floor13_B                       // NW +2
              translate < -800 0  800 > }
   object { Floor13_B                       // SW +2
              translate < -800 0 -800 > }

   object { Floor13_B                       // NNW +3
              translate <  -400 0  1200 > }
   object { Floor13_B                       // NNE +3
              translate <   400 0  1200 > }
   object { Floor13_B                       // SSW +3
              translate <  -400 0 -1200 > }
   object { Floor13_B                       // SSE +3
              translate <   400 0 -1200 > }

   object { Floor13_B                       // NE +3
              translate <  1200 0  1200 > }
   object { Floor13_B                       // NEE +3
              translate <  1200 0   400 > }
   object { Floor13_B                       // SEE +3
              translate <  1200 0  -400 > }
   object { Floor13_B                       // SW +3
              translate <  1200 0 -1200 > }
   object { Floor13_B                       // SE +3
              translate < -1200 0 -1200 > }
   object { Floor13_B                       // SWW +3
              translate < -1200 0  -400 > }
   object { Floor13_B                       // NWW +3
              translate < -1200 0   400 > }
   object { Floor13_B                       // NW +3
              translate < -1200 0  1200 > }
   }  // end composite ChekFloor1                        **********

/* ********************************************************************* */
// **********   MAIN LINE OF SCRIPT FILE    **********                   //
/* ********************************************************************* */


composite { ChekFloor1 }


/* ********************************************************************* */
/* END  OF  TEMPLE, GARDENS AND FLOORS ::  CKFLOOR1.POV   ************** */
/* ********************************************************************* */
