/* ********************************************************************* */
//   Filename: HOUSE00.POV                                               //
//   Michael Brendan Hurley      for     ShadowDancer Enterprizes, LTD.  //
//   HOUSE 00: Master copy of Our_House script              May-Sept 97  //
//   Final first drafts of all scene elements.                           //
/* ********************************************************************* */

/* ********************************************************************* */
//                           Global Definitions                          //
/* ********************************************************************* */

#include "basic.inc"                   // Lights Cameras Simple objects
#include "rooms.inc"                   // Textures, Complex Objects

/* ********************************************************************* */
/* ********************************************************************* */

// DEFINE DEFAULTS

#default { texture { ambient 0.6 } }   // ambient light

/* ********************************************************************* */

// DEFINE SKY  ***** *****

object { sphere { < 0 0 0 > 6000 }
         texture { White_Tex           //day
                   ambient 1.0
                   diffuse 0.0
                 }  //end texture
         color White
/*
         texture { MidBlue_Tex         //night
                   ambient 1.0
                   diffuse 0.0
                 }  //end texture
         color Blue
         texture { Bright_AquaBlue     //fancy day
                   scale < 1300 300 444 >
                   ambient 1.0
                   diffuse 0.0
                 }  //end texture
*/
       }  //end object Sky

/* ********************************************************************* */
/* ********************************************************************* */

// DECLARE TEST CAMERA  *****  set location and look_at  *****

#declare TestView =
camera {
   direction <   0    0     2 >
//   location  < 170   45    45 >        //mid shot SE HOUSEa.TGA
//   location  <  65   55   -90 >        //long shot
//   location  <  25  230   -10 >        //above center of 1st room
//   location  <  40  260   -40 >        //above center of Wing/South Wall
//   location  < -20  425    15 >        //above & s of Atrium center
//   location  <   0   40   300 >        //way N of north Wing
//   location  <-180   20   140 >        //way W      "

   location  < -100  95  -360 >        //
   look_at   <  -30  20     0 >        //

//   look_at   <   0   10     0 >        // scene center
//   look_at   < -50   20   105 >        //W Wall Wing2 1st floor
//   look_at   <   0   20   160 >        //N wall Wing 2nd floor
//   look_at   <   0   20   100 >        //Wing 2 south center
//   look_at   <  30   20    20 >        //center of Room 1
//   look_at   <  40   20    20 >        //center of Wing / South Wall
       }  //end of camera Test View

/* ********************************************************************* */
// DEFINE SCENE  *****   Our_House Master Scene Definition   ***** //
/* ********************************************************************* */

/* ********************************************************************* */
// LIGHTS!                        ***** DEFINE LIGHT SOURCES
/* ********************************************************************* */

//                                ***** global lighting
//object { light_source { FloodRear } }  // high rear flood light
//object { light_source { FloodSouth } } // low front flood light
//object { light_source { FloodSE2 } }   // high flood light
//object { light_source { FloodSW2 } }   // high flood light
//object { light_source { FloodNE2 } }   // high floor light
composite { Flood_Bank1 }                 //pseudo sun

//                                ***** spots on < 0 0 0 >
//object { light_source { SpotRight1 } } // +x +y +z spot light
//object { light_source { SpotLeft1 } }  // -x +y -z spot light
//object { light_source { SpotRight2 } } // +x -y -z spot light
//object { light_source { SpotLeft2 } }  // -x +y -z spot light

//                                ***** Test Locations
//object { light_source { TestSpot1 } }  //
//object { light_source { TestSpot2 } }  //
//object { light_source { TestSpot3 } }  //
//object { light_source { TestSpot4 } }  //
//object { light_source { TestSpot5 } }  //

//object { light_source { HallSpot1 } }  //
//object { light_source { HallSpot2 } }  //


/* ********************************************************************* */
// CAMERA!                        ***** POSITION CAMERA
/* ********************************************************************* */

camera { TestView }                    // Variable with each view
//camera { WayOverHigh }                 // < 0 900 -1 >
//camera { OverHigh }                    // < 0 650 -1 >
//camera { OverMed }                     // < 0 300 -1 >
//camera { OverLow }                     // < 0 100 -1 >
//camera { South1 }                      // <   0 20 -50 >
//camera { West1 }                       // < -50 20   0 >
//camera { North1 }                      // <   0 20  50 >
//camera { East1 }                       // <  50 20   0 >

/* ********************************************************************* */
// ACTION!                        ***** DESCRIBE Our_House SCENE
/* ********************************************************************* */

object { Test_Floor  texture { Grass } } // end Test Floor

composite { Atrium_A }                 // Central Room of Our_House  *****

composite { Wing_One  }                // east wing + ramada         *****

composite { Wing_One                   // west wing                  *****
            rotate < 0 180 0 >
            translate < -40 0 40 > }

composite { Wing_Two                   // north wing                 *****
            scale < 2 1 2 >                 //double size
            rotate < 0 90 0 >
            translate < -60 0 180 > }

composite { Wing_Two_Up                // north wing                 *****
            scale < 2 1 1 >
            translate < -80 20 160 > }      // 2nd. story

object    { Tower_Square
            texture { White_Marble }
            scale < 12 4 6 >
            translate < -20 0 195 > }       //under 2nd story fireplace
object    { Box_Plain                       //elevator shaft
            texture { Silver_Metal }
            color Violet
            scale < 5 20 5 >
            translate < 5 20 165 > }

composite { Hallway_N }                //north hallway               *****

composite { Wing_Three                 // the Round Tower Wing       *****
            translate < -120 0 110 > }      //west of Wing Two

composite { Round_Colonade
            translate < -100 0 125 > }      //to link with Wing Two
composite { Round_Colonade
            translate < -100 0 100 > }      //         "
composite { Round_Rafters
            translate < -100 0 100 > }      //         "
composite { Round_Rafters
            translate < -100 0 110 > }      //         "

                                       // Decore                     *****
composite { Pic_Frame_A
            translate < 30 15 37 > }   // cntr chimney Wing 1
object    { Picture_B
            translate < 30 0.2 20 > }  //actually a rug front of fireplace
composite { FirePlace_A
            scale < 1 1 1 >
            translate < 30 0 35 > }    // cntr north wall Wing 1

                                       // Landscaping                *****
composite { Tree_B   scale < 2 2 2 >  translate <  60 0  60 > }
composite { Tree_B   scale < 2 2 2 >  translate <  90 0  60 > }
composite { Tree_B   scale < 2 2 2 >  translate < 120 0  60 > }

object    { Hedge_B  scale < 4 2 2 >  translate <  30 0  50 > }
object    { Hedge_B  scale < 4 2 2 >  translate <  30 0 -10 > }
object    { Hedge_B  scale < 4 2 2 >  translate < -30 0  50 > }
object    { Hedge_B  scale < 4 2 2 >  translate < -30 0 -10 > }
object    { Hedge_B  scale < 4 2 2 >  translate <  30 0 -10 > }
composite { Patio_East  translate < 75 0 20 > }

composite { Front_Yard }               // Pool, Shrubry, Trees
composite { Pathway_1 }                // Garden path east
composite { Pathway_1                  // Garden path west
            rotate < 0 180 0 >
            translate < -40 0 -60 > }
composite { Front_Wall
            translate < -20 0 -150 > }

/* ********************************************************************* */
/* ********************************************************************* */

/*      STORAGE   *****

object { Test_Floor
         texture { Chex_Tex }
//         texture { Gray75_Tex }
//         texture { Grass }
       }                               //  end Test Floor

composite { Grid_Zero  translate < 0 0 0> }
composite { Grid_Plus  translate < 0 0 0> }
composite { Grid_Up    translate < 0 0 0> }
composite { Push_Pin  translate <  20 0 15 > } //markers
composite { Push_Pin  translate <  20 0 65 > }

                                       // Structural parts           *****
composite { Tower_A                    //Chrome thing WING10.TGA
            scale < 1.1 1.1 1.1 >
            translate < 7 0 33 > }          //NE corner Wing A
composite { Arbor_Fense }
composite { Arbor_Fense rotate < 0 180 0 > }
composite { Arbor_A scale < 1 1.5 1 > }

*/     //END STORAGE                                                 *****

/* ********************************************************************* */
/* END OF   House 00   Master    FILE                 ****************** */
/* ********************************************************************* */