/* ********************************************************************* */
//   Filename: TEMPLE1.POV                                               //
//   Master view of TEMPLE and Garden of Objects      Oct 1996 Ver 2.0   //
//   Michael Brendan Hurley     for     ShadowDancer Enterprizes, Ltd.   //
//   This is the original scene from which all the ChekFloors evolved.   //
//   The Temple  and  Garden of Objects was  started in  Sept 95  as a   //
//   demonstration of most  of the shapes and textures in the standard   //
//   POV include files.Many of the Objects are shown in close-up views   //
//   in their own script files. These files were written with the help   //
//   of a template script file which is included in this package.        //
//                                                                       //
/* ********************************************************************* */

/* ********************************************************************* */
//                           Global Definitions                          //
/* ********************************************************************* */

#include "basic.inc"                   // Lights Cameras Simple objects
#include "temple.inc"                  // Scene specific objects

/* ********************************************************************* */
/* ********************************************************************* */

// DEFINE DEFAULTS

#default { texture { ambient 0.3 } }   // ambient light
max_trace_level 10

/* ******************************************************************** */

//DEFINE SKY  *****   fuzzy strings of color   *****

object { sphere { < 0 0 0 > 35000 }        // 150000
         texture { Sky_Agate
            scale < 6000 90000 6000 >
            rotate < 55 0 0 >
            ambient 0.3
            diffuse 0.0
                 }  //end texture
         texture { Sky_Agate2
            scale < 5800 90000 5700 >
            rotate < 51 0 0 >
            ambient 0.3
            diffuse 0.0
                 }  //end texture
         color White                   // low resolution display color
       }  //end object Sky

/* ******************************************************************** */

// DECLARE TEST CAMERA  *****  set location and look_at  *****

#declare TestView =
camera {
  location  < -140.0  45.0  -110.0 >     //master view for TEMPLE1.TGA
  direction <   0.0   0.0    1.5 >
  up        <   0.0   1.0    0.0 >
  right     <   1.33  0.0    0.0 >
  look_at   <   0.0   5.0    0.0 >     // world center 5.0 above floor
       }  //end of camera Test View

/* ********************************************************************* */
/* ********************************************************************* */

// DEFINE SCENE  *****  TEST OF ASSORTED STANDARDIZED ELEMENTS     ***** //

// ********************************************************************* //
// LIGHTS!                        ***** DEFINE LIGHT SOURCES

//                                ***** for all scenes
object { light_source { FloodRear } }  // high rear flood light
object { light_source { FloodSouth } } // low front flood light
object { light_source { FloodSE } }    // high checker flood light
object { light_source { FloodSW } }    // high checker flood light

//                                ***** for center floor < 0 0 0 >
object { light_source { SpotRight1 } } // +x +y +z spot light
object { light_source { SpotLeft1 } }  // -x +y -z spot light
//object { light_source { SpotRight2 } } // +x -y -z spot light
//object { light_source { SpotLeft2 } }  // -x -y -z spot light

//                                ***** for center floor other objs
//object { light_source { HTSpot1 } }    // on HyperTower from +50y west
object { light_source { HTSpot2 } }    // on HyperTower from +50y east
object { light_source { TPSpot1 } }    // on TetraPile from +60y west
object { light_source { TPSpot2 } }    // on TetraPile from +60y east
//object { light_source { POSSpot1 } }   // on SW Pile o Spheres
object { light_source { BBSpot1 } }    // on SW Blob Box
object { light_source { SRSpot1 } }    // on NE Sphere Rods
//object { light_source { TGSpot } }     // on SW Twin Globs


// ********************************************************************* //
// CAMERA!                        ***** POSITION CAMERA

camera { TestView }                    // Variable with each view
//camera { OverHigh }                    // < 0 650 -1 >
//camera { OverMed }                     // < 0 300 -1 >
//camera { OverLow }                     // < 0 100 -1 >

//camera { South1 }                      // <   0 20 -50 >
//camera { West1 }                       // < -50 20   0 >
//camera { North1 }                      // <   0 20  50 >
//camera { East1 }                       // <  50 20   0 >

//camera { SouthWest1 }                  // < -25 20 -25 >
//camera { SouthWest2 }                  // < -50 20 -50 >
//camera { NorthWest1 }                  // < -25 20  25 >
//camera { NorthWest2 }                  // < -50 20  50 >
//camera { SouthEast1 }                  // < 25 20 -25 >
//camera { SouthEast2 }                  // < 50 20 -50 >
//camera { NorthEast1 }                  // < 25 20  25 >
//camera { NorthEast2 }                  // < 50 20  50 >


// ********************************************************************* //
// ACTION!                        ***** Position objects                 //
// Edited declaration to feature central Floor Temple scene              //

#declare ChekFloor1 =                  // Checker patern of Floors
composite {

   composite {                         // Central Floor

      object { Floor13_B }
      composite { Temple_B                  // Ver B Temple
                  scale < 2 2 2 >
                }  // end composite Temple
      composite { BiCorn_Hills              // Hills in wood textures
                  scale < 1.5 1.5 1.5 >
                  rotate < 0 25 0 >         // rotate obj +y = right
                  translate < 120 0 30 >    // due E of temple
                } // end of composite BiCorn 1
      composite { HyperTower                // NE of temple
                  translate < 44 10 57 >
                }  // end composite HyperTower
      composite { Pile_O_Spheres            // SW of temple
                  scale < 0.9 0.9 0.9 >
                  rotate < 0 0 80 >
                  translate < -50 0 -20 >
                }  // end composite P O S
      composite { Element_Tetra_3
                  translate < 13 0 -13 >    // S and E of temple
                  scale < 1.11 1.11 1.11 >
                }  // end composite Tetra 2
      composite { BiCorn_Hills              // Bi-Corn Hills in wood textures
                  scale < 3.2 1.50 2.70 >
                  translate < -60 0 220 >   // NW of 0 0 0
                  rotate < 0 -40 0 >        // rotate obj -y = to left
                } // end of composite BiCorn 2
      composite { Piri_Glass_B
                  translate < 50 0.5 -6 >   // due East of temple
                }  // end of composite Piri_Glass
      object { Element_Octa1
               rotate < 0 40 0 >
               translate < -22 5 22 >       // just N & W of temple
             }  // end of object Octa1
      composite { Blob_Box_B
                  translate < -35 0.3 -13 > // just SW of temple
                }  // end of composite Blob_Box
      composite { SphereRod_B               // NW of temple
                  translate < -32 4 35 >
                }  // end composite SphereRod B
      composite { Twin_Glob_B               // SW of temple
                  translate < -13 0 -28 >
                }  // end composite T_Globs

             }                         // end of Central floor

/* ********************************************************************* */

   composite {                         // start of NE+1    **********
      object { Floor13_B
                 translate < 400 0 400 > }
             } // end composite             end of NE +1   **********

   composite {                         // start of SE+1    **********
      object { Floor13_B
               translate < 400 0 -400 > }
             }  // end composite          end of SE+1      **********

   composite {                         // start of NW+1    **********
      object { Floor13_B
               translate < -400 0 400 > }
             }  // end of composite              NW +1     **********

   composite {                         // start of SW +1   **********
      object { Floor13_B
               translate < -400 0 -400 > }
             }  // end composite       end of SW +1        **********

/* ********************************************************************* */

   object { Floor13_B                       // E +2
              translate <  800 0    0 > }
   object { Floor13_B                       // N +2
              translate <    0 0  800 > }
   object { Floor13_B                       // SE +2
              translate <  800 0 -800 > }
   object { Floor13_B                       // NE +2
              translate <  800 0  800 > }

   }  // end composite ChekFloor1

/* ********************************************************************* */
// **********            MAIN LINE OF SCRIPT FILE             ********** //
/* ********************************************************************* */

composite { ChekFloor1 }

/* ********************************************************************* */
/* END OF  Temple 1  FILE                     ************************** */
/* ********************************************************************* */
