/* ********************************************************************* */
/*    TOWERS.INC                  Pov V.2 Include File of Definitions    */
/*    MBH for SDE, Ltd.                               Ver 1.0 Sept 97    */
/*       Declarations  to  support  Rooms,  Our_House,  Wings, etc.      */
/* ********************************************************************* */

/* ********************************************************************* */
/*                          Pillars, Roofs                               */
/* ********************************************************************* */

// DEFINE   very tall (+20y) pillar at <0 0 0>   *****

#declare Center_Pole =
object {                            
  intersection { Disk_Y }
                 texture { Green_World
                           turbulence 0.0   // Mix colors
                           rotate < 33 0 0 >// tilt texture
                         } // end texture
                 scale < 5 20 5 >           // Enlarge entire obj
                 color PaleGreen            // Low res. color
          } // end obj CenterPole

/* ********************************************************************* */

// DEFINE   Square Flat Roof   *****

#declare Roof_B =
object { box { UnitBox  scale < 10 1 10 > }
       } // end obj Roof B

/* ********************************************************************* */

// DEFINE   Conical Roof   *****

#declare Roof_Cone =
object { intersection { UCone }
         texture { oak
                   scale < 0.5 1 0.5 >
                   rotate < -20 0 0 >
                 } //end texture
         scale < 1.5 1.5 1.5 >              //to fit building
         translate < 0 3 0 >                //at top of structure
         color Orange
          } //end obj Cone

/* ********************************************************************* */

// DEFINE  Square sloped roof   *****

#declare  AFrame_Roof =
composite {
   object { box { UnitBox  scale < 4 0.5 4 > }
            texture { DMFDarkOak
                      reflection 0.1
                      phong 0.9 }
            rotate < 45 0 0 >
            translate < 0 2 2.5 >      //
            color NeonPink
          } //end obj box
   object { box { UnitBox  scale < 4 0.5 4 > }
            texture { DMFDarkOak
                      reflection 0.1
                      phong 0.9 }
            rotate < -45 0 0 >
            translate < 0 2 -2.5 >     //
            color ForestGreen
          } //end obj box
   object { box { UnitBox  scale < 4 0.5 4 > }
            texture { DMFDarkOak
                      reflection 0.1
                      phong 0.9 }
            translate < 0 0.5 0 >      // the base
            color Violet
          } //end obj box
// add end panels
          }  //  end composite A-Frame Roof

/* ********************************************************************* */

//  DEFINE  Double A-frame roof

#declare Double_AFrame =
composite {
composite { AFrame_Roof
            scale < 2 1 1 > }
composite { AFrame_Roof
            scale < 2 1 1 >
            rotate < 0 90 0 > }
          }  //  end composite Double AFrame

/* ********************************************************************* */

//   DEFINE   A beveled-edged square box: original version

#declare Roof_Two =
object {
   difference {
      intersection {
         intersection { Cube scale     //body of gem
                        < 1.0 0.5 1.0 > }  //2 units per side
                                       //beveled edges
         plane { < 0 1 0 > 0.5              // top front x edge
                 scale < 1.0 1.0 0.25 >
                 rotate < -45 0 0 >         
                 translate < 0 0.45 0 >
               } //end plane a
         plane { < 0 1 0 > 0.5              // top rear x edge
                 scale < 1.0 1.0 0.25 >
                 rotate < 45 0 0 >          
                 translate < 0 0.45 0 >
               } //end plane b
         plane { < 0 1 0 > 0.5              // top left z edge
                 scale < 1.0 1.0 0.25 >
                 rotate < -45 90 0 >
                 translate < 0 0.45 0 >
               } //end plane c
         plane { < 0 1 0 > 0.5              // top right z edge
                 scale < 1.0 1.0 0.25 >
                 rotate < 45 90 0 >
                 translate < 0 0.45 0 >
               } //end plane d
                   } //end intersection
              } //end difference
   color Orange
       } // end obj Roof Two

/* ********************************************************************* */

//   DEFINE   A beveled roof box: scaled for Wing One              *****

#declare Roof_Three =
object {
   difference {
      intersection {
         intersection { Cube scale     //body of roof
                        < 2.5 0.5 1.0 > }  //2.5 units x-axis
                                       //beveled edges
         plane { < 0 1 0 > 0.5              // top front x edge
                 scale < 2.5 1.0 0.25 >
                 rotate < -45 0 0 >
                 translate < 0 0.45 0 >
               } //end plane a
         plane { < 0 1 0 > 0.5              // top rear x edge
                 scale < 2.5 1.0 0.25 >
                 rotate < 45 0 0 >
                 translate < 0 0.45 0 >
               } //end plane b
         plane { < 0 1 0 > 0.5              // top left z edge
                 scale < 2.5 1.0 0.25 >
                 rotate < -45 90 0 >
                 translate < -1.5 0.45 0 >
               } //end plane c
         plane { < 0 1 0 > 0.5              // top right z edge
                 scale < 2.5 1.0 0.25 >
                 rotate < 45 90 0 >
                 translate < 1.5 0.45 0 >
               } //end plane d
                   } //end intersection
              } //end difference
   color Orange
       } // end obj Roof Three

/* ********************************************************************* */

//   DEFINE   A beveled-edged box, length in z-axix:               *****

#declare Roof_Four =
object {
   difference {
      intersection {
         intersection { Cube scale     //body of gem
                        < 1.0 0.5 2.5 > }
                                       //beveled edges
         plane { < 0 1 0 > 0.5              // top front x edge
                 scale < 1.0 0.5 2.5 >
                 rotate < -45 0 0 >
                 translate < 0 0.45 -1.5 >
               } //end plane a
         plane { < 0 1 0 > 0.5              // top rear x edge
                 scale < 1.0 0.5 2.5 >
                 rotate < 45 0 0 >
                 translate < 0 0.45 1.5 >
               } //end plane b
         plane { < 0 1 0 > 0.5              // top left z edge
                 scale < 2.5 1.0 0.25 >
                 rotate < -45 90 0 >
                 translate < 0 0.45 0 >
               } //end plane c
         plane { < 0 1 0 > 0.5              // top right z edge
                 scale < 2.5 1.0 0.25 >
                 rotate < 45 90 0 >
                 translate < 0 0.45 0 >
               } //end plane d
                   } //end intersection
              } //end difference
   color Orange
       } // end obj Roof Four

/* ********************************************************************* */

//   DEFINE   A beveled-edged roof: steep pitch scaled for Atrium  *****

#declare Roof_Five =
object {
   difference {
      intersection {
         intersection { Cube scale     // body of gem
                        < 25.0 4 25.0 > }  // 50 units per side
                                       // beveled edges
         plane { < 0 1 0 > 0                // top front, south x edge
                 scale < 1.0 1.0 0.25 >
                 rotate < -75 0 0 >
                 translate < 0 -3 -25 >
               } //end plane a
         plane { < 0 1 0 > 0                // top rear, north x edge
                 scale < 1.0 1.0 0.25 >
                 rotate < 75 0 0 >
                 translate < 0 -3 25 >
               } //end plane b
         plane { < 0 1 0 > 0                // top left z edge
                 scale < 1.0 1.0 0.25 >
                 rotate < -75 90 0 >
                 translate < -25 -3 0 >
               } //end plane c
         plane { < 0 1 0 > 0                // top right z edge
                 scale < 1.0 1.0 0.25 >
                 rotate < 75 90 0 >
                 translate < 25 -3 0 >
               } //end plane d
                   } //end intersection
              } //end difference
   color HuntersGreen
       } // end obj Roof Five

/* ********************************************************************* */

//   DEFINE  A beveled roof: steep pitch scaled for Wing Two       *****

#declare Roof_Six =
object {
   difference {
      intersection {
         intersection { Cube scale     // body of gem
                        < 34 6 24 > }
                                       // beveled edges
         plane { < 0 1 0 > 0                // top front, south x edge
                 scale < 1.0 1.0 0.25 >
                 rotate < -75 0 0 >
                 translate < 0 -3 -24 >
               } //end plane a
         plane { < 0 1 0 > 0                // top rear, north x edge
                 scale < 1.0 1.0 0.25 >
                 rotate < 75 0 0 >
                 translate < 0 -3 24 >
               } //end plane b
         plane { < 0 1 0 > 0                // top left z edge
                 scale < 1.0 1.0 0.25 >
                 rotate < -75 90 0 >
                 translate < -34 -3 0 >
               } //end plane c
         plane { < 0 1 0 > 0                // top right z edge
                 scale < 1.0 1.0 0.25 >
                 rotate < 75 90 0 >
                 translate < 34 -3 0 >
               } //end plane d
                   } //end intersection
              } //end difference
   color MandarinOrange
       } // end obj Roof Six

/* ********************************************************************* */

//   DEFINE   A beveled roof box: scaled for Wing Two Up           *****

#declare Roof_Seven =
object {
   difference {
      intersection {
         intersection { Cube scale     // body of gem
                        < 35 4 24 > }
                                       // beveled edges
         plane { < 0 1 0 > 0                // top front, south x edge
                 scale < 1.0 1.0 0.25 >
                 rotate < -75 0 0 >
                 translate < 0 -3 -23 >
               } //end plane a
         plane { < 0 1 0 > 0                // top rear, north x edge
                 scale < 1.0 1.0 0.25 >
                 rotate < 75 0 0 >
                 translate < 0 -3 23 >
               } //end plane b
         plane { < 0 1 0 > 0                // top left z edge
                 scale < 1.0 1.0 0.25 >
                 rotate < -75 90 0 >
                 translate < -34 -3 0 >
               } //end plane c
         plane { < 0 1 0 > 0                // top right z edge
                 scale < 1.0 1.0 0.25 >
                 rotate < 75 90 0 >
                 translate < 34 -3 0 >
               } //end plane d

                   } //end intersection
              } //end difference
   color Orange
       } // end obj Roof Seven

/* ********************************************************************* */
/*                           Define Towers                               */
/* ********************************************************************* */

//DEFINE  an Infantino-esque Tower

#declare Tower_A =
composite {
   object { sphere { < 0.0 0.0 0.0 > 1.0 }  //upper
            texture { Chrome_Metal
                      reflection 0.99 }
            scale < 1 1 1 >
            translate < 0 10 0 >
            color Red
          }  //end obj sphere
   object { intersection { Disk_Y }         //body
            texture { Chrome_Metal
                      reflection 0.99 }
            scale < 1 2 1 >
            translate < 0 12 0 >
            color Blue
          }  // end object Cylinder
   object { sphere { < 0.0 0.0 0.0 > 1.0 }  //lower
            texture { Chrome_Metal
                      reflection 0.99 }
            scale < 1 1 1 >
            translate < 0 14 0 >
            color Green
          }  //end obj sphere
   object { intersection { Disk_Y }         //stem
            texture { Chrome_Metal
                      reflection 0.99 }
            scale < 0.5 5 0.5 >
            translate < 0.25 5 0.25 >
            color Yellow
          }  // end object Cylinder
          } // end composite Tower A

/* ********************************************************************* */

// DEFINE   Cylinder Tower   *****

#declare Tower_Round =
object { Pillar_A
         scale < 1 0.2 1 >             //i.e. 1 1 1 Pillar A
         translate < 0 1 0 >           //base on floor
         color Aquamarine
        } // end Pillar

/* ********************************************************************* */

// DEFINE   Square Tower   *****

#declare Tower_Square =
object { box { UnitBox
               scale < 1 5 1 > }
         color Sienna
       } // end object Tower Square

/* ********************************************************************* */

// DEFINE   Round Tower + Cone Roof, scalable seperately here   *****
//                                   scalable together in script*****

#declare Tower_RC =
composite {
   object { Tower_Round                // round tower
            texture { Grnt20 }
            scale < 5 15 5 >
          } // end object Tower Round
   object { Roof_Cone                  // conical roof
            scale < 5 10 5 >
            translate < 0 14 0 >
          } // end object Roof Cone
          } // end composite Tower Round Cone

/* ********************************************************************* */

// DEFINE   Square Tower + A-Frame Roof, scalable seperately here   *****
//                                    scalable together in script   *****

#declare Tower_SA =
composite {
   object { Tower_Square
            texture { Blue_Agate
                      scale < 1 1 1 >
                      rotate < 10 0 0 > }
            scale < 5 7.5 5 >
          } //end Tower Square
   composite { AFrame_Roof
               scale < 1.4 1.3 1.4 >
               translate < 0 28.5 0 >
             } //end A-Frame Roof
          } // end composite Tower Square A-Frame

/* ********************************************************************* */

//   DEFINE  Square tower with double A-Frame roof

#declare Tower_SAA =
composite {
   composite { Double_AFrame
               translate < 0 13 0 > }
   object { Tower_Square
            texture { Blue_Agate
                      scale < 1 1 1 >
                      rotate < 10 0 0 > }
            scale < 4.5 4 4.5 >
          } //end Tower Square
          } // end composite Tower Square Double A

/* ********************************************************************* */
/* End TOWERS.INC                                                        */
/* ********************************************************************* */
